#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Wed Oct 10 20:45:03 2018

@author: patrickmcfarlane

scoreboard.py contains the ScoreBoard class that
enables API calls for two score board endpoints
"""

from .utils import api_call, parse_api_call
from datetime import datetime

class ScoreBoard:
    """ The ScoreBoard class contains all resources needed to use the
    score board API calls. `stats.nba.com <https://stats.nba.com>`_
    has the following score board API endpoints:

        - **scoreboard**: Live scores across the league, with series metadata \
        and standings information.
        - **scoreboardv2**: Live scores across the league, with series metadata \
        and standings information. Also, scoreboardv2 has ticket, win \
        probability, and team leader information.

    The ScoreBoard class has the following required parameters:

        @param **headers** (*dict*): Dictionary of request header information
            required by the API. Specifically, the API requires you to declare
            the 'User-Agent' key of the request header dictionary. More information
            can be found `here <https://stackoverflow.com/questions/46781563/
            how-to-obtain-a-json-response-from-the-stats-nba-com-api>`_ and
            an example request header dictionary can be found in the __init__.py
            file in the tests folder of this module.

        @param **league_id** (*str*): LeagueID in the API. String of a \
            two-digit number corresponding to the league. '00' is the NBA, \
            '10' is the WNBA, '01' is the ABA, and '20' is the G-League.

        @param **game_date** (*str*): GameDate in the API. String of a \
            date formatted as 'MM/DD/YYYY' representing the date for \
            which data is desired.

        @param **day_offset** (*str*): DayOffset in the API. String of an \
            integer representing days from or before the date given in \
            **game_date** for which data is desired. Positive values \
            indicate days into the future, zero represents the current \
            day, and negative values indicate days into the past.

    Attributes:

        **api_resp** (*dict*): JSON object of the API response. The API \
            response has three keys. The 'resource' key describes the \
            type of response returned (the endpoint in this instance). \
            The 'parameters' key describes the parameters provided in \
            the API call. The 'resultSets' key contains the data returned \
            in the API call.

        **data** (*dict*): A dictionary of response names. Each response \
            name is a key to a list of dictionaries containing the \
            corresponding data.
    """

    cur_day = datetime.today().day
    cur_month = datetime.today().month
    cur_year = str(datetime.today().year)
    if cur_day < 10:
        cur_day = '0' + str(cur_day)
    else:
        cur_day = str(cur_day)

    if cur_month < 10:
        cur_month = '0' + str(cur_month)
    else:
        cur_month = str(cur_month)

    current_date = cur_month + '/' + \
                   cur_day + '/' + \
                   cur_year

    def __init__(self, headers, endpoint='scoreboard',
                 league_id='00', game_date=current_date,
                 day_offset='0'):
        
        # Controlling the parameters depending on the endpoint
        params = {'LeagueID': league_id,
                  'GameDate': game_date,
                  'DayOffset': day_offset}

        self.api_resp = api_call(endpoint=endpoint,
                                 params=params,
                                 headers=headers)

        # Storing the API response in a dictionary called data
        # The results can come in different formats, namely a
        # dictionary keyed by either resultSets or resultSet
        self.data = parse_api_call(self.api_resp)



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Mon Dec 17 20:51:55 2018

@author: patrickmcfarlane
"""

HEADERS = {'Connection': 'close',
           'Host': 'stats.nba.com',
           'Origin': 'http://stats.nba.com',
           'Upgrade-Insecure-Requests': '1',
           'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_13_2)' + \
                         'AppleWebKit/537.36 (KHTML, like Gecko) ' + \
                         'Chrome/66.0.3359.117 Safari/537.36'}


#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Mon Oct  8 11:26:44 2018

@author: patrickmcfarlane

__init__.py

This script initializes the py_ball package
"""

name = 'py_ball'

__all__ = ['league', 'image', 'utils']



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Sun Jul 21 12:57:27 2019

@author: patrickmcfarlane

5/18/18 - 8/19/18
5/13/17 - 9/3/17
5/14/16 - 9/18/16
6/5/15 - 9/13/15
5/16/14 - 8/17/14
5/24/13 - 9/15/13
5/18/12 - 9/23/12
6/3/11 - 9/11/11
5/15/10 - 8/22/10
6/6/09 - 9/13/09
5/17/18 - 9/14/08 (14 teams!)

10/16/18 - 4/10/19
10/17/17 - 4/11/18
10/25/16 - 4/12/17
10/27/15 - 4/13/16
10/28/14 - 4/15/15
10/29/13 - 4/16/14
10/30/12 - 4/17/13
12/25/11 - 4/26/12***
10/26/10 - 4/13/11
10/27/09 - 4/14/10

OFF_RATING
DEF_RATING (weighted by lineup usage and availability)
OPP_OFF_RATING (exlcuding games against you)
OPP_DEF_RATING (weighted by lineup usage and availability)
HOME/AWAY
REST
DISTANCE TRAVELED
PREDICTED FOULS (Refs, foul rates, pace)
SCORE HOW (2nd CHANCE, OFF_TOV, PAINT, FB)
OPP SCORE HOW
"""

from vegas import Vegas
from datetime import datetime, timedelta
import pandas as pd
import time

HEADERS = {'Connection': 'close',
           'Host': 'sportsdatabase.com',
           'Origin': 'http://sportsdatabase.com',
           'Upgrade-Insecure-Requests': '1',
           'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_13_2)AppleWebKit/537.36 (KHTML, like Gecko) Chrome/66.0.3359.117 Safari/537.36'}

start_date = datetime(2019, 5, 24)
days = 65

full_df = pd.DataFrame()
num_games = 0
for day in range(days + 1):
    date = start_date + timedelta(days=day)
    print(date)
    years = str(date.year)
    if date.month <= 9:
        month = '0' + str(date.month)
    else:
        month = str(date.month)
    if date.day <= 9:
        day_str = '0' + str(date.day)
    else:
        day_str = str(date.day)

    t0 = time.time()
    date_str = years + month + day_str
    data = Vegas(HEADERS, date_str, 'wnba')
    if data.data != {}:
        data_df = pd.DataFrame(data.data)
        print(num_games)
        num_games += len(data_df)
        full_df = pd.concat([full_df, data_df], axis=0)
    delay = time.time() - t0
    print('Waiting ' + str(10*delay) + 's')
    time.sleep(10*delay)

full_df.to_csv('wnba_2019.csv', index=False)


#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Sat Dec 22 12:29:35 2018

@author: patrickmcfarlane

test_draft.py

This function contains the tests for
functions in the draft.py file
"""

from .__init__ import HEADERS
from ..draft import Draft

def test_draft_combine():
    """ tests the draftcombinestats endpoint of the Draft class
    """

    example_draft = Draft(headers=HEADERS)

    table_names = example_draft.data.keys()

    assert 'DraftCombineStats' in table_names

    example_player_stats = example_draft.data['DraftCombineStats'][0]

    assert list(example_player_stats.keys()) == ['SEASON',
                                                 'PLAYER_ID',
                                                 'FIRST_NAME',
                                                 'LAST_NAME',
                                                 'PLAYER_NAME',
                                                 'POSITION',
                                                 'HEIGHT_WO_SHOES',
                                                 'HEIGHT_WO_SHOES_FT_IN',
                                                 'HEIGHT_W_SHOES',
                                                 'HEIGHT_W_SHOES_FT_IN',
                                                 'WEIGHT',
                                                 'WINGSPAN',
                                                 'WINGSPAN_FT_IN',
                                                 'STANDING_REACH',
                                                 'STANDING_REACH_FT_IN',
                                                 'BODY_FAT_PCT',
                                                 'HAND_LENGTH',
                                                 'HAND_WIDTH',
                                                 'STANDING_VERTICAL_LEAP',
                                                 'MAX_VERTICAL_LEAP',
                                                 'LANE_AGILITY_TIME',
                                                 'MODIFIED_LANE_AGILITY_TIME',
                                                 'THREE_QUARTER_SPRINT',
                                                 'BENCH_PRESS',
                                                 'SPOT_FIFTEEN_CORNER_LEFT',
                                                 'SPOT_FIFTEEN_BREAK_LEFT',
                                                 'SPOT_FIFTEEN_TOP_KEY',
                                                 'SPOT_FIFTEEN_BREAK_RIGHT',
                                                 'SPOT_FIFTEEN_CORNER_RIGHT',
                                                 'SPOT_COLLEGE_CORNER_LEFT',
                                                 'SPOT_COLLEGE_BREAK_LEFT',
                                                 'SPOT_COLLEGE_TOP_KEY',
                                                 'SPOT_COLLEGE_BREAK_RIGHT',
                                                 'SPOT_COLLEGE_CORNER_RIGHT',
                                                 'SPOT_NBA_CORNER_LEFT',
                                                 'SPOT_NBA_BREAK_LEFT',
                                                 'SPOT_NBA_TOP_KEY',
                                                 'SPOT_NBA_BREAK_RIGHT',
                                                 'SPOT_NBA_CORNER_RIGHT',
                                                 'OFF_DRIB_FIFTEEN_BREAK_LEFT',
                                                 'OFF_DRIB_FIFTEEN_TOP_KEY',
                                                 'OFF_DRIB_FIFTEEN_BREAK_RIGHT',
                                                 'OFF_DRIB_COLLEGE_BREAK_LEFT',
                                                 'OFF_DRIB_COLLEGE_TOP_KEY',
                                                 'OFF_DRIB_COLLEGE_BREAK_RIGHT',
                                                 'ON_MOVE_FIFTEEN',
                                                 'ON_MOVE_COLLEGE']

def test_draft_history():
    """ tests the drafthistory endpoint of the Draft class
    """

    example_draft = Draft(headers=HEADERS, endpoint='drafthistory')

    table_names = example_draft.data.keys()

    assert 'DraftHistory' in table_names

    example_history = example_draft.data['DraftHistory'][0]

    assert list(example_history.keys()) == ['PERSON_ID',
                                            'PLAYER_NAME',
                                            'SEASON',
                                            'ROUND_NUMBER',
                                            'ROUND_PICK',
                                            'OVERALL_PICK',
                                            'TEAM_ID',
                                            'TEAM_CITY',
                                            'TEAM_NAME',
                                            'TEAM_ABBREVIATION',
                                            'ORGANIZATION',
                                            'ORGANIZATION_TYPE']




#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Sat Dec 22 15:08:46 2018

@author: patrickmcfarlane

test_league_dash.py

This function contains the tests for
functions in the league_dash.py file
"""

from .__init__ import HEADERS
from ..league_dash import LeagueDash

def test_lineups_dash():
    """ tests the leaguedashlineups endpoint of the LeagueDash class
    """

    example_league = LeagueDash(headers=HEADERS)

    table_names = example_league.data.keys()

    assert 'Lineups' in table_names

    example_lineups = example_league.data['Lineups'][0]

    assert list(example_lineups.keys()) == ['GROUP_SET',
                                            'GROUP_ID',
                                            'GROUP_NAME',
                                            'TEAM_ID',
                                            'TEAM_ABBREVIATION',
                                            'GP',
                                            'W',
                                            'L',
                                            'W_PCT',
                                            'MIN',
                                            'FGM',
                                            'FGA',
                                            'FG_PCT',
                                            'FG3M',
                                            'FG3A',
                                            'FG3_PCT',
                                            'FTM',
                                            'FTA',
                                            'FT_PCT',
                                            'OREB',
                                            'DREB',
                                            'REB',
                                            'AST',
                                            'TOV',
                                            'STL',
                                            'BLK',
                                            'BLKA',
                                            'PF',
                                            'PFD',
                                            'PTS',
                                            'PLUS_MINUS',
                                            'GP_RANK',
                                            'W_RANK',
                                            'L_RANK',
                                            'W_PCT_RANK',
                                            'MIN_RANK',
                                            'FGM_RANK',
                                            'FGA_RANK',
                                            'FG_PCT_RANK',
                                            'FG3M_RANK',
                                            'FG3A_RANK',
                                            'FG3_PCT_RANK',
                                            'FTM_RANK',
                                            'FTA_RANK',
                                            'FT_PCT_RANK',
                                            'OREB_RANK',
                                            'DREB_RANK',
                                            'REB_RANK',
                                            'AST_RANK',
                                            'TOV_RANK',
                                            'STL_RANK',
                                            'BLK_RANK',
                                            'BLKA_RANK',
                                            'PF_RANK',
                                            'PFD_RANK',
                                            'PTS_RANK',
                                            'PLUS_MINUS_RANK']

def test_bio_dash():
    """ tests the leaguedashplayerbiostats endpoint of the LeagueDash class
    """

    example_league = LeagueDash(headers=HEADERS,
                                endpoint='leaguedashplayerbiostats')

    table_names = example_league.data.keys()

    assert 'LeagueDashPlayerBioStats' in table_names

    example_bio = example_league.data['LeagueDashPlayerBioStats'][0]

    assert list(example_bio.keys()) == ['PLAYER_ID',
                                        'PLAYER_NAME',
                                        'TEAM_ID',
                                        'TEAM_ABBREVIATION',
                                        'AGE',
                                        'PLAYER_HEIGHT',
                                        'PLAYER_HEIGHT_INCHES',
                                        'PLAYER_WEIGHT',
                                        'COLLEGE',
                                        'COUNTRY',
                                        'DRAFT_YEAR',
                                        'DRAFT_ROUND',
                                        'DRAFT_NUMBER',
                                        'GP',
                                        'PTS',
                                        'REB',
                                        'AST',
                                        'NET_RATING',
                                        'OREB_PCT',
                                        'DREB_PCT',
                                        'USG_PCT',
                                        'TS_PCT',
                                        'AST_PCT']

def test_clutch_dash():
    """ tests the leaguedashplayerclutch endpoint of the LeagueDash class
    """

    example_league = LeagueDash(headers=HEADERS,
                                endpoint='leaguedashplayerclutch')

    table_names = example_league.data.keys()

    assert 'LeagueDashPlayerClutch' in table_names

    example_clutch = example_league.data['LeagueDashPlayerClutch'][0]

    assert list(example_clutch.keys()) == ['GROUP_SET',
                                           'PLAYER_ID',
                                           'PLAYER_NAME',
                                           'TEAM_ID',
                                           'TEAM_ABBREVIATION',
                                           'AGE',
                                           'GP',
                                           'W',
                                           'L',
                                           'W_PCT',
                                           'MIN',
                                           'FGM',
                                           'FGA',
                                           'FG_PCT',
                                           'FG3M',
                                           'FG3A',
                                           'FG3_PCT',
                                           'FTM',
                                           'FTA',
                                           'FT_PCT',
                                           'OREB',
                                           'DREB',
                                           'REB',
                                           'AST',
                                           'TOV',
                                           'STL',
                                           'BLK',
                                           'BLKA',
                                           'PF',
                                           'PFD',
                                           'PTS',
                                           'PLUS_MINUS',
                                           'NBA_FANTASY_PTS',
                                           'DD2',
                                           'TD3',
                                           'GP_RANK',
                                           'W_RANK',
                                           'L_RANK',
                                           'W_PCT_RANK',
                                           'MIN_RANK',
                                           'FGM_RANK',
                                           'FGA_RANK',
                                           'FG_PCT_RANK',
                                           'FG3M_RANK',
                                           'FG3A_RANK',
                                           'FG3_PCT_RANK',
                                           'FTM_RANK',
                                           'FTA_RANK',
                                           'FT_PCT_RANK',
                                           'OREB_RANK',
                                           'DREB_RANK',
                                           'REB_RANK',
                                           'AST_RANK',
                                           'TOV_RANK',
                                           'STL_RANK',
                                           'BLK_RANK',
                                           'BLKA_RANK',
                                           'PF_RANK',
                                           'PFD_RANK',
                                           'PTS_RANK',
                                           'PLUS_MINUS_RANK',
                                           'NBA_FANTASY_PTS_RANK',
                                           'DD2_RANK',
                                           'TD3_RANK',
                                           'CFID',
                                           'CFPARAMS']

def test_shot_dash():
    """ tests the leaguedashplayershotlocations endpoint of the LeagueDash class
    """

    example_league = LeagueDash(headers=HEADERS,
                                endpoint='leaguedashplayershotlocations')

    table_names = example_league.data.keys()

    assert 'ShotLocations' in table_names

    example_shots = example_league.data['ShotLocations'][0]

    assert list(example_shots.keys()) == ['PLAYER_ID',
                                          'PLAYER_NAME',
                                          'TEAM_ID',
                                          'TEAM_ABBREVIATION',
                                          'AGE',
                                          'FGM_Restricted_Area',
                                          'FGA_Restricted_Area',
                                          'FG_PCT_Restricted_Area',
                                          'FGM_In_The_Paint_(Non-RA)',
                                          'FGA_In_The_Paint_(Non-RA)',
                                          'FG_PCT_In_The_Paint_(Non-RA)',
                                          'FGM_Mid-Range',
                                          'FGA_Mid-Range',
                                          'FG_PCT_Mid-Range',
                                          'FGM_Left_Corner_3',
                                          'FGA_Left_Corner_3',
                                          'FG_PCT_Left_Corner_3',
                                          'FGM_Right_Corner_3',
                                          'FGA_Right_Corner_3',
                                          'FG_PCT_Right_Corner_3',
                                          'FGM_Above_the_Break_3',
                                          'FGA_Above_the_Break_3',
                                          'FG_PCT_Above_the_Break_3',
                                          'FGM_Backcourt',
                                          'FGA_Backcourt',
                                          'FG_PCT_Backcourt']

def test_shooting_dash():
    """ tests the leaguedashplayerptshot endpoint of the LeagueDash class
    """

    example_league = LeagueDash(headers=HEADERS,
                                endpoint='leaguedashplayerptshot')

    table_names = example_league.data.keys()

    assert 'LeagueDashPTShots' in table_names

    example_shots = example_league.data['LeagueDashPTShots'][0]

    assert list(example_shots.keys()) == ['PLAYER_ID',
                                          'PLAYER_NAME',
                                          'PLAYER_LAST_TEAM_ID',
                                          'PLAYER_LAST_TEAM_ABBREVIATION',
                                          'AGE',
                                          'GP',
                                          'G',
                                          'FGA_FREQUENCY',
                                          'FGM',
                                          'FGA',
                                          'FG_PCT',
                                          'EFG_PCT',
                                          'FG2A_FREQUENCY',
                                          'FG2M',
                                          'FG2A',
                                          'FG2_PCT',
                                          'FG3A_FREQUENCY',
                                          'FG3M',
                                          'FG3A',
                                          'FG3_PCT']

def test_stats_dash():
    """ tests the leaguedashplayerstats endpoint of the LeagueDash class
    """

    example_league = LeagueDash(headers=HEADERS,
                                endpoint='leaguedashplayerstats')

    table_names = example_league.data.keys()

    assert 'LeagueDashPlayerStats' in table_names

    example_stats = example_league.data['LeagueDashPlayerStats'][0]

    assert list(example_stats.keys()) == ['PLAYER_ID',
                                          'PLAYER_NAME',
                                          'TEAM_ID',
                                          'TEAM_ABBREVIATION',
                                          'AGE',
                                          'GP',
                                          'W',
                                          'L',
                                          'W_PCT',
                                          'MIN',
                                          'FGM',
                                          'FGA',
                                          'FG_PCT',
                                          'FG3M',
                                          'FG3A',
                                          'FG3_PCT',
                                          'FTM',
                                          'FTA',
                                          'FT_PCT',
                                          'OREB',
                                          'DREB',
                                          'REB',
                                          'AST',
                                          'TOV',
                                          'STL',
                                          'BLK',
                                          'BLKA',
                                          'PF',
                                          'PFD',
                                          'PTS',
                                          'PLUS_MINUS',
                                          'NBA_FANTASY_PTS',
                                          'DD2',
                                          'TD3',
                                          'GP_RANK',
                                          'W_RANK',
                                          'L_RANK',
                                          'W_PCT_RANK',
                                          'MIN_RANK',
                                          'FGM_RANK',
                                          'FGA_RANK',
                                          'FG_PCT_RANK',
                                          'FG3M_RANK',
                                          'FG3A_RANK',
                                          'FG3_PCT_RANK',
                                          'FTM_RANK',
                                          'FTA_RANK',
                                          'FT_PCT_RANK',
                                          'OREB_RANK',
                                          'DREB_RANK',
                                          'REB_RANK',
                                          'AST_RANK',
                                          'TOV_RANK',
                                          'STL_RANK',
                                          'BLK_RANK',
                                          'BLKA_RANK',
                                          'PF_RANK',
                                          'PFD_RANK',
                                          'PTS_RANK',
                                          'PLUS_MINUS_RANK',
                                          'NBA_FANTASY_PTS_RANK',
                                          'DD2_RANK',
                                          'TD3_RANK',
                                          'CFID',
                                          'CFPARAMS']

def test_defend_dash():
    """ tests the leaguedashptdefend endpoint of the LeagueDash class
    """

    example_league = LeagueDash(headers=HEADERS,
                                endpoint='leaguedashptdefend')

    table_names = example_league.data.keys()

    assert 'LeagueDashPTDefend' in table_names

    example_defend = example_league.data['LeagueDashPTDefend'][0]

    assert list(example_defend.keys()) == ['CLOSE_DEF_PERSON_ID',
                                           'PLAYER_NAME',
                                           'PLAYER_LAST_TEAM_ID',
                                           'PLAYER_LAST_TEAM_ABBREVIATION',
                                           'PLAYER_POSITION',
                                           'AGE',
                                           'GP',
                                           'G',
                                           'FREQ',
                                           'D_FGM',
                                           'D_FGA',
                                           'D_FG_PCT',
                                           'NORMAL_FG_PCT',
                                           'PCT_PLUSMINUS']

def test_team_defend_dash():
    """ tests the leaguedashptteamdefend endpoint of the LeagueDash class
    """

    example_league = LeagueDash(headers=HEADERS,
                                endpoint='leaguedashptteamdefend')

    table_names = example_league.data.keys()

    assert 'LeagueDashPtTeamDefend' in table_names

    example_defend = example_league.data['LeagueDashPtTeamDefend'][0]

    assert list(example_defend.keys()) == ['TEAM_ID',
                                           'TEAM_NAME',
                                           'TEAM_ABBREVIATION',
                                           'GP',
                                           'G',
                                           'FREQ',
                                           'D_FGM',
                                           'D_FGA',
                                           'D_FG_PCT',
                                           'NORMAL_FG_PCT',
                                           'PCT_PLUSMINUS']
    
def test_team_shooting_dash():
    """ tests the leaguedashteamptshot endpoint of the LeagueDash class
    """

    example_league = LeagueDash(headers=HEADERS,
                                endpoint='leaguedashteamptshot')

    table_names = example_league.data.keys()

    assert 'LeagueDashPTShots' in table_names

    example_shot = example_league.data['LeagueDashPTShots'][0]

    assert list(example_shot.keys()) == ['TEAM_ID',
                                         'TEAM_NAME',
                                         'TEAM_ABBREVIATION',
                                         'GP',
                                         'G',
                                         'FGA_FREQUENCY',
                                         'FGM',
                                         'FGA',
                                         'FG_PCT',
                                         'EFG_PCT',
                                         'FG2A_FREQUENCY',
                                         'FG2M',
                                         'FG2A',
                                         'FG2_PCT',
                                         'FG3A_FREQUENCY',
                                         'FG3M',
                                         'FG3A',
                                         'FG3_PCT']



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Wed Apr 3 19:29:03 2018

@author: patrickmcfarlane

event.py contains the Event class that
enables API calls for the events endpoints
"""

from .utils import api_video_call, parse_api_call

class Event:
    """ The Event class contains all resources needed to use the 
    event API calls. `stats.nba.com <https://stats.nba.com>`_
    has the following video-related API endpoints:

        - **events**: Game play-by-play video clips at the \
            play-level

    The Event class has the following required parameters:

        @param **game_id** (*str*): GameID in the API. 10-digit string \
            that represents a unique game. The format is two leading zeroes, \
            followed by a season indicator number ('1' for preseason, \
            '2' for regular season, '4' for the post-season), \
            then the trailing digits of the season in which the game \
            took place (e.g. '17' for the 2017-18 season). The following \
            5 digits increment from '00001' in order as the season progresses. \
            For example, '0021600001' is the **game_id** of the first game \
            of the 2016-17 NBA regular season.

        @param **season** (*str*): Season in the API. String of a two-year \
            season in a YYYY-ZZ format, where the ZZ are the last two \
            digits of the following year. For example, '2017-18' is a valid \
            value of **season** and represents the 2017-18 NBA season.

        @param **game_event_id** (*str*): GameEventID in the API. String of \
            an integer indicating the sequence of play-by-play events in a
            game, starting from 1.

    Attributes:

        **api_resp** (*dict*): JSON object of the API response. The API \
            response has three keys. The 'resource' key describes the \
            type of response returned ('events' in this instance). \
            The 'parameters' key describes the parameters provided in \
            the API call. The 'resultSets' key contains the data returned \
            in the API call.

        **data** (*dict*): A dictionary of response names. Each response \
            name is a key to a list of dictionaries containing the \
            corresponding data.
    """

    def __init__(self, headers, game_id, endpoint='events',
                 season='2017-18', game_event_id='154'):

        # Controlling the parameters depending on the endpoint
        params = {'GameID': game_id,
                  'Season': season,
                  'GameEventID': game_event_id,
                  'flag': '1'}

        self.api_resp = api_video_call(endpoint=endpoint,
                                       params=params,
                                       headers=headers)



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Sat Dec 22 13:04:35 2018

@author: patrickmcfarlane

test_leaderboard.py

This function contains the tests for
functions in the leaderboard.py file
"""

from .__init__ import HEADERS
from ..leaderboard import LeaderBoard

def test_homepage_leaders():
    """ tests the homepageleaders endpoint of the LeaderBoard class
    """

    example_leaderboard = LeaderBoard(headers=HEADERS)

    table_names = example_leaderboard.data.keys()

    assert 'HomePageLeaders' in table_names
    assert 'LeagueAverage' in table_names
    assert 'LeagueMax' in table_names

    example_leaders = example_leaderboard.data['HomePageLeaders'][0]
    example_average = example_leaderboard.data['LeagueAverage'][0]
    example_max = example_leaderboard.data['LeagueMax'][0]

    assert list(example_leaders.keys()) == ['RANK',
                                            'PLAYERID',
                                            'PLAYER',
                                            'TEAM_ID',
                                            'TEAM_ABBREVIATION',
                                            'TEAM_NAME',
                                            'PTS',
                                            'FG_PCT',
                                            'FG3_PCT',
                                            'FT_PCT',
                                            'EFG_PCT',
                                            'TS_PCT',
                                            'PTS_PER48']

    assert list(example_average.keys()) == ['PTS',
                                            'FG_PCT',
                                            'FG3_PCT',
                                            'FT_PCT',
                                            'EFG_PCT',
                                            'TS_PCT',
                                            'PTS_PER48']

    assert list(example_max.keys()) == ['PTS',
                                        'FG_PCT',
                                        'FG3_PCT',
                                        'FT_PCT',
                                        'EFG_PCT',
                                        'TS_PCT',
                                        'PTS_PER48']
    
def test_homepage():
    """ tests the homepagev2 endpoint of the LeaderBoard class
    """

    example_leaderboard = LeaderBoard(headers=HEADERS,
                                      endpoint='homepagev2')

    table_names = example_leaderboard.data.keys()

    assert 'HomePageStat1' in table_names
    assert 'HomePageStat2' in table_names
    assert 'HomePageStat3' in table_names
    assert 'HomePageStat4' in table_names
    assert 'HomePageStat5' in table_names
    assert 'HomePageStat6' in table_names
    assert 'HomePageStat7' in table_names
    assert 'HomePageStat8' in table_names

    example_homestat1 = example_leaderboard.data['HomePageStat1'][0]
    example_homestat2 = example_leaderboard.data['HomePageStat2'][0]
    example_homestat3 = example_leaderboard.data['HomePageStat3'][0]
    example_homestat4 = example_leaderboard.data['HomePageStat4'][0]
    example_homestat5 = example_leaderboard.data['HomePageStat5'][0]
    example_homestat6 = example_leaderboard.data['HomePageStat6'][0]
    example_homestat7 = example_leaderboard.data['HomePageStat7'][0]
    example_homestat8 = example_leaderboard.data['HomePageStat8'][0]

    assert list(example_homestat1.keys()) == ['RANK',
                                              'PLAYER_ID',
                                              'PLAYER',
                                              'TEAM_ID',
                                              'TEAM_ABBREVIATION',
                                              'TEAM_NAME',
                                              'JERSEY_NUM',
                                              'PLAYER_POSITION',
                                              'DIST_MILES']

    assert list(example_homestat2.keys()) == ['RANK',
                                              'PLAYER_ID',
                                              'PLAYER',
                                              'TEAM_ID',
                                              'TEAM_ABBREVIATION',
                                              'TEAM_NAME',
                                              'JERSEY_NUM',
                                              'PLAYER_POSITION',
                                              'AST_POINTS_CREATED']

    assert list(example_homestat3.keys()) == ['RANK',
                                              'PLAYER_ID',
                                              'PLAYER',
                                              'TEAM_ID',
                                              'TEAM_ABBREVIATION',
                                              'TEAM_NAME',
                                              'JERSEY_NUM',
                                              'PLAYER_POSITION',
                                              'DRIVES']

    assert list(example_homestat4.keys()) == ['RANK',
                                              'PLAYER_ID',
                                              'PLAYER',
                                              'TEAM_ID',
                                              'TEAM_ABBREVIATION',
                                              'TEAM_NAME',
                                              'JERSEY_NUM',
                                              'PLAYER_POSITION',
                                              'NUM_TOUCHES']

    assert list(example_homestat5.keys()) == ['RANK',
                                              'PLAYER_ID',
                                              'PLAYER',
                                              'TEAM_ID',
                                              'TEAM_ABBREVIATION',
                                              'TEAM_NAME',
                                              'JERSEY_NUM',
                                              'PLAYER_POSITION',
                                              'POST_TOUCHES']

    assert list(example_homestat6.keys()) == ['RANK',
                                              'PLAYER_ID',
                                              'PLAYER',
                                              'TEAM_ID',
                                              'TEAM_ABBREVIATION',
                                              'TEAM_NAME',
                                              'JERSEY_NUM',
                                              'PLAYER_POSITION',
                                              'REB_CONTEST']

    assert list(example_homestat7.keys()) == ['RANK',
                                              'PLAYER_ID',
                                              'PLAYER',
                                              'TEAM_ID',
                                              'TEAM_ABBREVIATION',
                                              'TEAM_NAME',
                                              'JERSEY_NUM',
                                              'PLAYER_POSITION',
                                              'CATCH_SHOOT_PTS']

    assert list(example_homestat8.keys()) == ['RANK',
                                              'PLAYER_ID',
                                              'PLAYER',
                                              'TEAM_ID',
                                              'TEAM_ABBREVIATION',
                                              'TEAM_NAME',
                                              'JERSEY_NUM',
                                              'PLAYER_POSITION',
                                              'PULL_UP_PTS']

def test_leaderstiles():
    """ tests the leaderstiles endpoint of the LeaderBoard class
    """

    example_leaderboard = LeaderBoard(headers=HEADERS, endpoint='leaderstiles')

    table_names = example_leaderboard.data.keys()

    assert 'LeadersTiles' in table_names
    assert 'AllTimeSeasonHigh' in table_names
    assert 'LastSeasonHigh' in table_names
    assert 'LowSeasonHigh' in table_names

    example_leaders = example_leaderboard.data['LeadersTiles'][0]
    example_all_high = example_leaderboard.data['AllTimeSeasonHigh'][0]
    example_high = example_leaderboard.data['LastSeasonHigh'][0]
    example_low = example_leaderboard.data['LowSeasonHigh'][0]

    assert list(example_leaders.keys()) == ['RANK',
                                            'PLAYER_ID',
                                            'PLAYER',
                                            'TEAM_ID',
                                            'TEAM_ABBREVIATION',
                                            'TEAM_NAME',
                                            'PTS']

    assert list(example_all_high.keys()) == ['PLAYER_ID',
                                             'PLAYER_NAME',
                                             'PTS',
                                             'SEASON_YEAR',
                                             'TEAM_ID',
                                             'TEAM_ABBREVIATION',
                                             'TEAM_NAME']

    assert list(example_high.keys()) == ['RANK',
                                         'PLAYER_ID',
                                         'PLAYER',
                                         'TEAM_ID',
                                         'TEAM_ABBREVIATION',
                                         'TEAM_NAME',
                                         'PTS']

    assert list(example_low.keys()) == ['PLAYER_ID',
                                        'PLAYER_NAME',
                                        'PTS',
                                        'SEASON_YEAR',
                                        'TEAM_ID',
                                        'TEAM_ABBREVIATION',
                                        'TEAM_NAME']

def test_leaders():
    """ tests the leagueleaders endpoint of the LeaderBoard class
    """

    example_leaderboard = LeaderBoard(headers=HEADERS,
                                      endpoint='leagueleaders')

    table_names = example_leaderboard.data.keys()

    assert 'LeagueLeaders' in table_names

    example_leaders = example_leaderboard.data['LeagueLeaders'][0]

    assert list(example_leaders.keys()) == ['PLAYER_ID',
                                            'RANK',
                                            'PLAYER',
                                            'TEAM',
                                            'GP',
                                            'MIN',
                                            'FGM',
                                            'FGA',
                                            'FG_PCT',
                                            'FG3M',
                                            'FG3A',
                                            'FG3_PCT',
                                            'FTM',
                                            'FTA',
                                            'FT_PCT',
                                            'OREB',
                                            'DREB',
                                            'REB',
                                            'AST',
                                            'STL',
                                            'BLK',
                                            'TOV',
                                            'PTS',
                                            'EFF']



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Sat Dec 22 15:37:02 2018

@author: patrickmcfarlane

test_playbyplay.py

This function contains the tests for
functions in the playbyplay.py file
"""

from .__init__ import HEADERS
from ..playbyplay import PlayByPlay

def test_playbyplay():
    """ tests the playbyplay endpoint of the PlayByPlay class
    """

    example_pbp = PlayByPlay(headers=HEADERS,
                             game_id='0021500002')

    table_names = example_pbp.data.keys()

    assert 'PlayByPlay' in table_names
    assert 'AvailableVideo' in table_names

    example_game = example_pbp.data['PlayByPlay'][0]
    example_video = example_pbp.data['AvailableVideo'][0]

    assert list(example_game.keys()) == ['GAME_ID',
                                         'EVENTNUM',
                                         'EVENTMSGTYPE',
                                         'EVENTMSGACTIONTYPE',
                                         'PERIOD',
                                         'WCTIMESTRING',
                                         'PCTIMESTRING',
                                         'HOMEDESCRIPTION',
                                         'NEUTRALDESCRIPTION',
                                         'VISITORDESCRIPTION',
                                         'SCORE',
                                         'SCOREMARGIN']

    assert list(example_video.keys()) == ['VIDEO_AVAILABLE_FLAG']
    
def test_playbyplayv2():
    """ tests the playbyplayv2 endpoint of the PlayByPlay class
    """

    example_pbp = PlayByPlay(headers=HEADERS,
                             endpoint='playbyplayv2',
                             game_id='0021500002')

    table_names = example_pbp.data.keys()

    assert 'PlayByPlay' in table_names
    assert 'AvailableVideo' in table_names

    example_game = example_pbp.data['PlayByPlay'][0]
    example_video = example_pbp.data['AvailableVideo'][0]

    assert list(example_game.keys()) == ['GAME_ID',
                                         'EVENTNUM',
                                         'EVENTMSGTYPE',
                                         'EVENTMSGACTIONTYPE',
                                         'PERIOD',
                                         'WCTIMESTRING',
                                         'PCTIMESTRING',
                                         'HOMEDESCRIPTION',
                                         'NEUTRALDESCRIPTION',
                                         'VISITORDESCRIPTION',
                                         'SCORE',
                                         'SCOREMARGIN',
                                         'PERSON1TYPE',
                                         'PLAYER1_ID',
                                         'PLAYER1_NAME',
                                         'PLAYER1_TEAM_ID',
                                         'PLAYER1_TEAM_CITY',
                                         'PLAYER1_TEAM_NICKNAME',
                                         'PLAYER1_TEAM_ABBREVIATION',
                                         'PERSON2TYPE',
                                         'PLAYER2_ID',
                                         'PLAYER2_NAME',
                                         'PLAYER2_TEAM_ID',
                                         'PLAYER2_TEAM_CITY',
                                         'PLAYER2_TEAM_NICKNAME',
                                         'PLAYER2_TEAM_ABBREVIATION',
                                         'PERSON3TYPE',
                                         'PLAYER3_ID',
                                         'PLAYER3_NAME',
                                         'PLAYER3_TEAM_ID',
                                         'PLAYER3_TEAM_CITY',
                                         'PLAYER3_TEAM_NICKNAME',
                                         'PLAYER3_TEAM_ABBREVIATION']

    assert list(example_video.keys()) == ['VIDEO_AVAILABLE_FLAG']



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Mon Oct 22 19:22:00 2018

@author: patrickmcfarlane

image.py contains the Headshot and Logo classes that
enables API calls for two score board endpoints
"""

from PIL import Image
import requests
from io import BytesIO
from cairosvg import svg2png

BASE_NBA_URL = 'https://ak-static.cms.nba.com/wp-content/uploads/' + \
                'headshots/nba/{team}/{season}/260x190/{player_id}.png'
BASE_WNBA_URL = 'https://ak-static.cms.nba.com/wp-content/uploads/' + \
                'headshots/wnba/{player_id}.png'
BASE_G_LEAGUE_URL = 'https://ak-static.cms.nba.com/wp-content/uploads/' + \
                    'headshots/dleague/{player_id}.png'

BASE_NBA_LOGO_URL = 'https://stats.nba.com/media/img/teams/' + \
                    'logos/season/{year}/{team}_logo.svg'
                    
BASE_WNBA_LOGO_URL = 'https://ak-static.cms.nba.com/wp-content/' + \
                     'themes/wnba-child/img/logos/' + \
                     '{team}-primary-logo.svg'

BASE_G_LEAGUE_LOGO_URL = 'https://stats.gleague.nba.com/media/' + \
                         'img/teams/logos/{team}.svg'
                     
ID_TO_TEAM_NBA = {'1610612761': 'TOR', '1610612743': 'DEN',
                  '1610612765': 'DET', '1610612740': 'NOP',
                  '1610612749': 'MIL', '1610612744': 'GSW',
                  '1610612759': 'SAS', '1610612757': 'POR',
                  '1610612746': 'LAC', '1610612742': 'DAL',
                  '1610612763': 'MEM', '1610612755': 'PHI',
                  '1610612738': 'BOS', '1610612750': 'MIN',
                  '1610612766': 'CHA', '1610612754': 'IND',
                  '1610612753': 'ORL', '1610612748': 'MIA',
                  '1610612745': 'HOU', '1610612758': 'SAC',
                  '1610612762': 'UTA', '1610612751': 'BKN',
                  '1610612737': 'ATL', '1610612756': 'PHX',
                  '1610612764': 'WAS', '1610612752': 'NYK',
                  '1610612760': 'OKC', '1610612747': 'LAL',
                  '1610612739': 'CLE', '1610612741': 'CHI'}

ID_TO_TEAM_WNBA = {'1611661330': 'dream', '1611661321': 'wings',
                   '1611661320': 'sparks', '1611661317': 'mercury',
                   '1611661329': 'sky', '1611661325': 'fever',
                   '1611661324': 'lynx', '1611661328': 'storm',
                   '1611661323': 'sun', '1611661319': 'aces',
                   '1611661313': 'liberty', '1611661322': 'mystics'}

ID_TO_TEAM_G_LEAGUE = {'1612709908': 'RGV', '1612709902': 'SCW',
                       '1612709926': 'MHU', '1612709914': 'STO',
                       '1612709903': 'SLC', '1612709921': 'LIN',
                       '1612709889': 'OKL', '1612709925': 'LAK',
                       '1612709920': 'RAP', '1612709919': 'WES',
                       '1612709917': 'GRD', '1612709923': 'WCB',
                       '1612709913': 'ERI', '1612709904': 'SXF',
                       '1612709909': 'DEL', '1612709928': 'CAP',
                       '1612709911': 'IWA', '1612709924': 'ACC',
                       '1612709910': 'FWN', '1612709905': 'SBL',
                       '1612709918': 'TEX', '1612709927': 'WIS',
                       '1612709922': 'GBO', '1612709915': 'MNE',
                       '1612709890': 'AUS', '1612709893': 'CTN',
                       '1612709900': 'NAS'}

class Headshot:
    """ The Headshot class contains all resources needed to pull
    headshot images for NBA, G-League, and WNBA players.

    The Headshot class has the following required parameters:

        @param **league** (*str*): String, either 'WNBA', 'G', or 'NBA',
            to the league in which the desired player or team plays.

        @param **player_id** (*str*): String of an \
            integer corresponding to a player ID for a given player.

        @param **team_id** (*str*): String of a 10-digit \
            integer that uniquely identifies a team for which data \
            is to be returned.

        @param **season** (*str*): String of a year in YYYY format \
            corresponding to the year in which the NBA season begins.

    Attributes:

        **image** (*PngImageFile*): Image file of the desired headshot.
            Note that this image file is not saved locally, but stored
            in the Headshot class object.

    """

    def __init__(self, league='WNBA',
                 player_id='203400', team_id='',
                 season=''):
        
        # Controlling the parameters depending on the endpoint
        if league == 'WNBA':
            response = requests.get(BASE_WNBA_URL.format(player_id=player_id))
        elif league == 'NBA':
            response = requests.get(BASE_NBA_URL.format(player_id=player_id,
                                                        team=team_id,
                                                        season=season))
        elif league == 'G':
            response = requests.get(BASE_G_LEAGUE_URL.format(player_id=player_id))

        im = Image.open(BytesIO(response.content))
        self.image = im


class Logo:
    """ The Logo class contains all resources needed to pull
    logo images for NBA, G-League, and WNBA players.

    The Logo class has the following required parameters:

        @param **league** (*str*): String, either 'WNBA', 'G', or 'NBA',
            to the league in which the desired player plays.

        @param **team_id** (*str*): String of a 10-digit \
            integer that uniquely identifies a team for which data \
            is to be returned.

        @param **season_year** (*str*): String of a two-year season \
            year in a YYYY-ZZ format, where the ZZ are the \
            last two digits of the following year. For example, \
            '2017-18' is a valid value of **season_year** and \
            represents the 2017-18 NBA season. **season_year** is \
            only required for NBA logos.

    Attributes:

        **image** (*PngImageFile*): Image file of the desired headshot.
            Note that this image file is not saved locally, but stored
            in the Headshot class object.

    """

    def __init__(self, league='WNBA',
                 team_id='1611661319',
                 season_year='2017-18'):

        # Controlling the parameters depending on the endpoint
        if league == 'WNBA':
            team_str = ID_TO_TEAM_WNBA[team_id]
            response = requests.get(BASE_WNBA_LOGO_URL.format(team=team_str))
        elif league == 'NBA':
            team_str = ID_TO_TEAM_NBA[team_id]
            response = requests.get(BASE_NBA_LOGO_URL.format(team=team_str,
                                                             year=season_year))
        elif league == 'G':
            team_str = ID_TO_TEAM_G_LEAGUE[team_id]
            response = requests.get(BASE_G_LEAGUE_LOGO_URL.format(team=team_str))

        new_bites = svg2png(bytestring=response.content,
                            write_to=None)
        im = Image.open(BytesIO(new_bites))
        self.image = im



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Sun Feb  23 13:02:05 2020

@author: patrickmcfarlane

wnba_salaries.py contains the functions
to gather NBA salary information
"""

from requests import get

SALARY_URL = "https://www.spotrac.com/wnba/cap/"

URL_TO_ID_WNBA = {'https://www.spotrac.com/redirect/team/347/cap/': '1611661324',
                  'https://www.spotrac.com/redirect/team/345/cap/': '1611661319',
                  'https://www.spotrac.com/redirect/team/348/cap/': '1611661313',
                  'https://www.spotrac.com/redirect/team/341/cap/': '1611661329',
                  'https://www.spotrac.com/redirect/team/346/cap/': '1611661320',
                  'https://www.spotrac.com/redirect/team/344/cap/': '1611661325',
                  'https://www.spotrac.com/redirect/team/340/cap/': '1611661330',
                  'https://www.spotrac.com/redirect/team/342/cap/': '1611661323',
                  'https://www.spotrac.com/redirect/team/349/cap/': '1611661317',
                  'https://www.spotrac.com/redirect/team/351/cap/': '1611661322',
                  'https://www.spotrac.com/redirect/team/350/cap/': '1611661328',
                  'https://www.spotrac.com/redirect/team/343/cap/': '1611661321'}


def team_salary_values(html_text, season):
    """ team_salary_values returns a dictionary of
    salary information keyed by NBA team ID

    @param **html_text** (*str*): String of the HTML response
    from SALARY_URL
    @param **season** (*int*): Integer of season in YYYY
    format

    Returns:

        **team_salaries** (*dict*): Dictionary keyed by NBA
            team ID with a list of yearly salaries (followed
            by team salary URL) as values
    """
    value_str = '<td '
    team_salaries = {}
    wnba_teams = 12

    for teams in range(0, wnba_teams):
        team_list = []
        start_ind = html_text.find('<a')
        end_ind = html_text.find('</a>')
        team_key = html_text[start_ind + 2: end_ind]
        team_key = team_key[team_key.find('href="') + 6:team_key.find('">')]
        team_key = team_key.replace('-' + str(season), '')
        for col_count in range(0, 8):
            end_ind = html_text.find('">')
            html_text = html_text[end_ind + 2: ]
            end_ind = html_text.find('</td>')
            val = html_text[:end_ind]
            if '</a>' in val:
                val = val.replace('</a>', '')
            if "<span style='display:none'>" in val:
                val = val.replace("<span style='display:none'>", '')
                end_val = val.find('</span>')
                val = val[ :end_val]
            team_list.append(val)
            html_text = html_text[end_ind + 5:]
        start_ind = html_text.find(value_str) + len(value_str)
        html_text = html_text[start_ind: ]

        team_list.append(team_key.replace('cap', 'cap-' + str(season)))
        team_salaries[URL_TO_ID_WNBA[team_key]] = team_list

    return team_salaries


def player_salary_values(html_text):
    """ player_salary_values returns a dictionary of
    salary information keyed by Hoopshype player ID

    @param **html_text** (*str*): String of the HTML response
    from a Hoopshype team URL

    Returns:

        **player_salaries** (*dict*): Dictionary keyed by SpotRac
            player ID with a list of yearly salaries (followed
            by player salary URL) as values
    """
    value_str = '<span'
    player_salaries = {}
    url_val = html_text.find('<a')
    total_val = html_text.find('<td class="player">Active Roster Cap</td>')

    while url_val < total_val:
        player_list = []
        option_list = []
        start_ind = html_text.find('<a')
        end_ind = html_text.find('</a>')
        play_key = html_text[start_ind + 2: end_ind]
        play_key = play_key[play_key.find('href="') + 6:play_key.find('">')]
        player_key = play_key.split('/')[-2]
        #html_text = html_text[end_ind + 4:]
        for col_count in range(0, 9):
            if col_count < 6:
                start_ind = html_text.find(value_str) + len(value_str)
                html_text = html_text[start_ind:]
                start_ind = html_text.find('">') + 2
                end_ind = html_text.find('</span>')
                end_len = 7
            elif col_count == 6:
                start_ind = html_text.find("<td") + 3
                html_text = html_text[start_ind:]
                start_ind = html_text.find('">') + 2
                if 'option-' in html_text[:start_ind]:
                    option_start = html_text.find('option-') + 7
                    option_end = html_text.find(' "')
                    option_list.append(html_text[option_start:option_end])
                end_ind = html_text.find('<input')
                end_len = 6
            elif col_count == 7:
                start_ind = html_text.find(value_str) + len(value_str)
                html_text = html_text[start_ind:]
                start_ind = html_text.find('" >') + 3
                end_ind = html_text.find(' </span>')
                end_len = 8
            else:
                start_ind = html_text.find("<td") + 3
                html_text = html_text[start_ind:]
                start_ind = html_text.find('" >') + 3
                end_ind = html_text.find('</td>')
                end_len = 5
            try:
                salary_value = html_text[start_ind:end_ind]
            except:
                salary_value = 0
            player_list.append(salary_value)
            html_text = html_text[end_ind + end_len:]

        player_list.append(play_key)
        player_salaries[player_key] = {}
        player_salaries[player_key]['salary'] = player_list
        player_salaries[player_key]['options'] = option_list

        total_val = html_text.find('<td class="player">Active Roster Cap</td>')
        url_val = html_text.find('<a')

    return player_salaries


def get_team_salary(season):
    """ This function pulls team salary information
    from `spotrac.com <https://www.spotrac.com/wnba/cap/>`

    @param **season** (*int*): Integer of season in YYYY
    format

    Returns:

        **team_salaries** (*dict*): Dictionary keyed by WNBA
            team ID with a list of yearly salaries (followed
            by team salary URL) as values

        **column_list** (*list*): List of column names for team
            salary information
    """

    api_resp = get(SALARY_URL + str(season))
    html_text = api_resp.text
    sorted_str = 'The total cap $ for a team">Total Cap'
    table_index = html_text.find(sorted_str)
    html_text = html_text[table_index:]

    sorted_str = '<td class="center">'
    table_index = html_text.find(sorted_str)
    html_text = html_text[table_index:]

    column_list = ['Rank', 'Team', 'Signed', 'Average Age',
                   'Active Cap', 'Dead Cap', 'Total Cap',
                   'Cap Space', 'URL']

    team_salaries = team_salary_values(html_text, season)

    return team_salaries, column_list


def get_player_salary(team_url):
    """ This function pulls player salary information
    from `spotrac.com <https://www.spotrac.com/wnba/cap/>``

    @param team_url (str): String of URL corresponding
    to a single team's salary

    Returns:

        **player_salaries** (*dict*): Dictionary keyed by Spotrac
            player ID with a list of yearly salaries as values

        **column_list** (*list*): List of column names for team
            salary information
    """

    api_resp = get(team_url)
    html_text = api_resp.text
    sorted_str = '<td class="player">'
    
    table_index = html_text.find(sorted_str)
    html_text = html_text[table_index:]
    column_list = ['Player', 'Age', 'Position',
                   'YOE', 'Signed Using', 'Base Salary',
                   'Dead Cap', 'Cap Figure', 'Cap %', 'URL']

    player_salaries = player_salary_values(html_text)

    return player_salaries, column_list


class TeamSalaries:
    """ The TeamSalaries class contains all resources needed
    to scrape team salary information from
    `spotrac.com <https://www.spotrac.com/wnba/cap/>`.
    This class contains both team total salary as well as individual
    player breakdowns

    @param **season** (*int*): Integer of season in YYYY
    format

    Attributes:

        **totals** (*dict*): Dictionary keyed by WNBA
            team ID with a list of yearly salaries (followed
            by team salary URL) as values

        **totals_columns** (*list*): List of column names for team
            salary information

        **team_player_salaries** (*dict*): Dictionary keyed by both WNBA
            team ID and Hoopshype player ID with values containing both
            salary and option information

        **team_player_columns** (*list*): List of column names for team-player
            salary information
    """

    def __init__(self, season):

        # First, total team salary information is pulled
        team_salaries, column_list = get_team_salary(season)
        self.totals = team_salaries
        self.totals_columns = column_list
        team_player_salary = {}
        for team_id in team_salaries:
            team_url = team_salaries[team_id][-1]
            player_salaries, column_list = get_player_salary(team_url)
            team_player_salary[team_id] = player_salaries

        self.team_player_salaries = team_player_salary
        self.team_player_columns = column_list


#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Wed May 22 19:00:44 2019

@author: patrickmcfarlane

wnba_shots.py contains the Shots class that
enables API calls for WNBA shot-related
data
"""

from .utils import wnba_shot_call

class Shots:
    """ The Shots class contains all resources needed
    to use the shot-related WNBA data. `data.wnba.com <https://data.wnba.com>`_
    has the following endpoints:

        - **pbp**: Shot-related data, including location, player \
        and associated metadata.

    The Shots class has the following required parameters:

        @param **headers** (*dict*): Dictionary of request header information
            required by the API. Specifically, the API requires you to declare
            the 'User-Agent' key of the request header dictionary. More information
            can be found `here <https://stackoverflow.com/questions/46781563/
            how-to-obtain-a-json-response-from-the-stats-nba-com-api>`_ and
            an example request header dictionary can be found in the __init__.py
            file in the tests folder of this module.

        @param **season** (*str*): Season in the API. String of a one-year \
            season in a YYYY format. For example, '2017' is a valid \
            value of **season** and represents the 2017 WNBA season.

        @param **game_id** (*str*): GameID in the API. 10-digit string \
            that represents a unique game. The format is two leading digits \
            ('10'), followed by a season indicator number ('1' for preseason, \
            '2' for regular season, '4' for the post-season), \
            then the trailing digits of the season in which the game \
            took place (e.g. '17' for the 2017 season). The following \
            5 digits increment from '00001' in order as the season progresses. \
            For example, '1021600001' is the **game_id** of the first game \
            of the 2016 WNBA regular season.

    Attributes:

        **data** (*dict*): A list of dictionaries containing a play. Each list
        contains play-by-play data for one game.
    """
    def __init__(self, headers, season='2018', game_id='1021800050'):

        params = {'season': season, 'game_id': game_id}
        self.data = wnba_shot_call(params=params, headers=headers)



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Mon Dec 24 09:06:50 2018

@author: patrickmcfarlane

test_team.py

This function contains the tests for
functions in the team.py file
"""

import time

from .__init__ import HEADERS
from ..team import Team

def test_team_clutch():
    """ tests the teamdashboardbyclutch endpoint of the Team class
    """

    time.sleep(1)
    example_team = Team(headers=HEADERS,
                          endpoint='teamdashboardbyclutch')

    table_names = example_team.data.keys()

    assert 'OverallTeamDashboard' in table_names
    assert 'Last5Min5PointTeamDashboard' in table_names
    assert 'Last3Min5PointTeamDashboard' in table_names
    assert 'Last1Min5PointTeamDashboard' in table_names
    assert 'Last30Sec3PointTeamDashboard' in table_names
    assert 'Last10Sec3PointTeamDashboard' in table_names
    assert 'Last5MinPlusMinus5PointTeamDashboard' in table_names
    assert 'Last3MinPlusMinus5PointTeamDashboard' in table_names
    assert 'Last1MinPlusMinus5PointTeamDashboard' in table_names
    assert 'Last30Sec3Point2TeamDashboard' in table_names
    assert 'Last10Sec3Point2TeamDashboard' in table_names

    example_overall = example_team.data['OverallTeamDashboard'][0]
    example_last5_5 = example_team.data['Last5Min5PointTeamDashboard'][0]
    example_last3_5 = example_team.data['Last3Min5PointTeamDashboard'][0]
    example_last1_5 = example_team.data['Last1Min5PointTeamDashboard'][0]
    example_last30_3 = example_team.data['Last30Sec3PointTeamDashboard'][0]
    example_last10_3 = example_team.data['Last10Sec3PointTeamDashboard'][0]
    example_last5 = example_team.data['Last5MinPlusMinus5PointTeamDashboard'][0]
    example_last3 = example_team.data['Last3MinPlusMinus5PointTeamDashboard'][0]
    example_last1 = example_team.data['Last1MinPlusMinus5PointTeamDashboard'][0]
    example_last30_3_2 = example_team.data['Last30Sec3Point2TeamDashboard'][0]
    example_last10_3_2 = example_team.data['Last10Sec3Point2TeamDashboard'][0]

    columns = ['GROUP_SET',
               'GROUP_VALUE',
               'GP',
               'W',
               'L',
               'W_PCT',
               'MIN',
               'FGM',
               'FGA',
               'FG_PCT',
               'FG3M',
               'FG3A',
               'FG3_PCT',
               'FTM',
               'FTA',
               'FT_PCT',
               'OREB',
               'DREB',
               'REB',
               'AST',
               'TOV',
               'STL',
               'BLK',
               'BLKA',
               'PF',
               'PFD',
               'PTS',
               'PLUS_MINUS',
               'GP_RANK',
               'W_RANK',
               'L_RANK',
               'W_PCT_RANK',
               'MIN_RANK',
               'FGM_RANK',
               'FGA_RANK',
               'FG_PCT_RANK',
               'FG3M_RANK',
               'FG3A_RANK',
               'FG3_PCT_RANK',
               'FTM_RANK',
               'FTA_RANK',
               'FT_PCT_RANK',
               'OREB_RANK',
               'DREB_RANK',
               'REB_RANK',
               'AST_RANK',
               'TOV_RANK',
               'STL_RANK',
               'BLK_RANK',
               'BLKA_RANK',
               'PF_RANK',
               'PFD_RANK',
               'PTS_RANK',
               'PLUS_MINUS_RANK',
               'CFID',
               'CFPARAMS']

    assert list(example_overall.keys()) == columns

    assert list(example_last5_5.keys()) == columns

    assert list(example_last3_5.keys()) == columns

    assert list(example_last1_5.keys()) == columns

    assert list(example_last30_3.keys()) == columns

    assert list(example_last10_3.keys()) == columns

    assert list(example_last5.keys()) == columns

    assert list(example_last3.keys()) == columns

    assert list(example_last1.keys()) == columns

    assert list(example_last30_3_2.keys()) == columns

    assert list(example_last10_3_2.keys()) == columns


def test_team_gamesplits():
    """ tests the teamdashboardbygamesplits endpoint of the Team class
    """

    time.sleep(1)
    example_team = Team(headers=HEADERS,
                        endpoint='teamdashboardbygamesplits')

    table_names = example_team.data.keys()

    assert 'OverallTeamDashboard' in table_names
    assert 'ByHalfTeamDashboard' in table_names
    assert 'ByPeriodTeamDashboard' in table_names
    assert 'ByScoreMarginTeamDashboard' in table_names
    assert 'ByActualMarginTeamDashboard' in table_names

    example_overall = example_team.data['OverallTeamDashboard'][0]
    example_half = example_team.data['ByHalfTeamDashboard'][0]
    example_period = example_team.data['ByPeriodTeamDashboard'][0]
    example_score = example_team.data['ByScoreMarginTeamDashboard'][0]
    example_margin = example_team.data['ByActualMarginTeamDashboard'][0]

    columns = ['GROUP_SET',
               'GROUP_VALUE',
               'GP',
               'W',
               'L',
               'W_PCT',
               'MIN',
               'FGM',
               'FGA',
               'FG_PCT',
               'FG3M',
               'FG3A',
               'FG3_PCT',
               'FTM',
               'FTA',
               'FT_PCT',
               'OREB',
               'DREB',
               'REB',
               'AST',
               'TOV',
               'STL',
               'BLK',
               'BLKA',
               'PF',
               'PFD',
               'PTS',
               'PLUS_MINUS',
               'GP_RANK',
               'W_RANK',
               'L_RANK',
               'W_PCT_RANK',
               'MIN_RANK',
               'FGM_RANK',
               'FGA_RANK',
               'FG_PCT_RANK',
               'FG3M_RANK',
               'FG3A_RANK',
               'FG3_PCT_RANK',
               'FTM_RANK',
               'FTA_RANK',
               'FT_PCT_RANK',
               'OREB_RANK',
               'DREB_RANK',
               'REB_RANK',
               'AST_RANK',
               'TOV_RANK',
               'STL_RANK',
               'BLK_RANK',
               'BLKA_RANK',
               'PF_RANK',
               'PFD_RANK',
               'PTS_RANK',
               'PLUS_MINUS_RANK',
               'CFID',
               'CFPARAMS']

    assert list(example_overall.keys()) == columns

    assert list(example_half.keys()) == columns

    assert list(example_period.keys()) == columns

    assert list(example_score.keys()) == columns

    assert list(example_margin.keys()) == columns

def test_team_generalsplits():
    """ tests the teamdashboardbygeneralsplits endpoint of the Team class
    """

    time.sleep(1)
    example_team = Team(headers=HEADERS,
                        endpoint='teamdashboardbygeneralsplits')

    table_names = example_team.data.keys()

    assert 'OverallTeamDashboard' in table_names
    assert 'LocationTeamDashboard' in table_names
    assert 'WinsLossesTeamDashboard' in table_names
    assert 'MonthTeamDashboard' in table_names
    assert 'PrePostAllStarTeamDashboard' in table_names
    assert 'DaysRestTeamDashboard' in table_names

    example_overall = example_team.data['OverallTeamDashboard'][0]
    example_location = example_team.data['LocationTeamDashboard'][0]
    example_wl = example_team.data['WinsLossesTeamDashboard'][0]
    example_month = example_team.data['MonthTeamDashboard'][0]
    example_star = example_team.data['PrePostAllStarTeamDashboard'][0]
    example_rest = example_team.data['DaysRestTeamDashboard'][0]

    columns = ['GROUP_SET',
               'GROUP_VALUE',
               'SEASON_YEAR',
               'GP',
               'W',
               'L',
               'W_PCT',
               'MIN',
               'FGM',
               'FGA',
               'FG_PCT',
               'FG3M',
               'FG3A',
               'FG3_PCT',
               'FTM',
               'FTA',
               'FT_PCT',
               'OREB',
               'DREB',
               'REB',
               'AST',
               'TOV',
               'STL',
               'BLK',
               'BLKA',
               'PF',
               'PFD',
               'PTS',
               'PLUS_MINUS',
               'GP_RANK',
               'W_RANK',
               'L_RANK',
               'W_PCT_RANK',
               'MIN_RANK',
               'FGM_RANK',
               'FGA_RANK',
               'FG_PCT_RANK',
               'FG3M_RANK',
               'FG3A_RANK',
               'FG3_PCT_RANK',
               'FTM_RANK',
               'FTA_RANK',
               'FT_PCT_RANK',
               'OREB_RANK',
               'DREB_RANK',
               'REB_RANK',
               'AST_RANK',
               'TOV_RANK',
               'STL_RANK',
               'BLK_RANK',
               'BLKA_RANK',
               'PF_RANK',
               'PFD_RANK',
               'PTS_RANK',
               'PLUS_MINUS_RANK',
               'CFID',
               'CFPARAMS']

    assert list(example_overall.keys()) == columns

    assert list(example_location.keys()) == ['GROUP_SET',
                                             'GROUP_VALUE',
                                             'TEAM_GAME_LOCATION',
                                             'GP',
                                             'W',
                                             'L',
                                             'W_PCT',
                                             'MIN',
                                             'FGM',
                                             'FGA',
                                             'FG_PCT',
                                             'FG3M',
                                             'FG3A',
                                             'FG3_PCT',
                                             'FTM',
                                             'FTA',
                                             'FT_PCT',
                                             'OREB',
                                             'DREB',
                                             'REB',
                                             'AST',
                                             'TOV',
                                             'STL',
                                             'BLK',
                                             'BLKA',
                                             'PF',
                                             'PFD',
                                             'PTS',
                                             'PLUS_MINUS',
                                             'GP_RANK',
                                             'W_RANK',
                                             'L_RANK',
                                             'W_PCT_RANK',
                                             'MIN_RANK',
                                             'FGM_RANK',
                                             'FGA_RANK',
                                             'FG_PCT_RANK',
                                             'FG3M_RANK',
                                             'FG3A_RANK',
                                             'FG3_PCT_RANK',
                                             'FTM_RANK',
                                             'FTA_RANK',
                                             'FT_PCT_RANK',
                                             'OREB_RANK',
                                             'DREB_RANK',
                                             'REB_RANK',
                                             'AST_RANK',
                                             'TOV_RANK',
                                             'STL_RANK',
                                             'BLK_RANK',
                                             'BLKA_RANK',
                                             'PF_RANK',
                                             'PFD_RANK',
                                             'PTS_RANK',
                                             'PLUS_MINUS_RANK',
                                             'CFID',
                                             'CFPARAMS']

    assert list(example_wl.keys()) == ['GROUP_SET',
                                       'GROUP_VALUE',
                                       'GAME_RESULT',
                                       'GP',
                                       'W',
                                       'L',
                                       'W_PCT',
                                       'MIN',
                                       'FGM',
                                       'FGA',
                                       'FG_PCT',
                                       'FG3M',
                                       'FG3A',
                                       'FG3_PCT',
                                       'FTM',
                                       'FTA',
                                       'FT_PCT',
                                       'OREB',
                                       'DREB',
                                       'REB',
                                       'AST',
                                       'TOV',
                                       'STL',
                                       'BLK',
                                       'BLKA',
                                       'PF',
                                       'PFD',
                                       'PTS',
                                       'PLUS_MINUS',
                                       'GP_RANK',
                                       'W_RANK',
                                       'L_RANK',
                                       'W_PCT_RANK',
                                       'MIN_RANK',
                                       'FGM_RANK',
                                       'FGA_RANK',
                                       'FG_PCT_RANK',
                                       'FG3M_RANK',
                                       'FG3A_RANK',
                                       'FG3_PCT_RANK',
                                       'FTM_RANK',
                                       'FTA_RANK',
                                       'FT_PCT_RANK',
                                       'OREB_RANK',
                                       'DREB_RANK',
                                       'REB_RANK',
                                       'AST_RANK',
                                       'TOV_RANK',
                                       'STL_RANK',
                                       'BLK_RANK',
                                       'BLKA_RANK',
                                       'PF_RANK',
                                       'PFD_RANK',
                                       'PTS_RANK',
                                       'PLUS_MINUS_RANK',
                                       'CFID',
                                       'CFPARAMS']

    assert list(example_month.keys()) == ['GROUP_SET',
                                          'GROUP_VALUE',
                                          'SEASON_MONTH_NAME',
                                          'GP',
                                          'W',
                                          'L',
                                          'W_PCT',
                                          'MIN',
                                          'FGM',
                                          'FGA',
                                          'FG_PCT',
                                          'FG3M',
                                          'FG3A',
                                          'FG3_PCT',
                                          'FTM',
                                          'FTA',
                                          'FT_PCT',
                                          'OREB',
                                          'DREB',
                                          'REB',
                                          'AST',
                                          'TOV',
                                          'STL',
                                          'BLK',
                                          'BLKA',
                                          'PF',
                                          'PFD',
                                          'PTS',
                                          'PLUS_MINUS',
                                          'GP_RANK',
                                          'W_RANK',
                                          'L_RANK',
                                          'W_PCT_RANK',
                                          'MIN_RANK',
                                          'FGM_RANK',
                                          'FGA_RANK',
                                          'FG_PCT_RANK',
                                          'FG3M_RANK',
                                          'FG3A_RANK',
                                          'FG3_PCT_RANK',
                                          'FTM_RANK',
                                          'FTA_RANK',
                                          'FT_PCT_RANK',
                                          'OREB_RANK',
                                          'DREB_RANK',
                                          'REB_RANK',
                                          'AST_RANK',
                                          'TOV_RANK',
                                          'STL_RANK',
                                          'BLK_RANK',
                                          'BLKA_RANK',
                                          'PF_RANK',
                                          'PFD_RANK',
                                          'PTS_RANK',
                                          'PLUS_MINUS_RANK',
                                          'CFID',
                                          'CFPARAMS']

    assert list(example_star.keys()) == ['GROUP_SET',
                                         'GROUP_VALUE',
                                         'SEASON_SEGMENT',
                                         'GP',
                                         'W',
                                         'L',
                                         'W_PCT',
                                         'MIN',
                                         'FGM',
                                         'FGA',
                                         'FG_PCT',
                                         'FG3M',
                                         'FG3A',
                                         'FG3_PCT',
                                         'FTM',
                                         'FTA',
                                         'FT_PCT',
                                         'OREB',
                                         'DREB',
                                         'REB',
                                         'AST',
                                         'TOV',
                                         'STL',
                                         'BLK',
                                         'BLKA',
                                         'PF',
                                         'PFD',
                                         'PTS',
                                         'PLUS_MINUS',
                                         'GP_RANK',
                                         'W_RANK',
                                         'L_RANK',
                                         'W_PCT_RANK',
                                         'MIN_RANK',
                                         'FGM_RANK',
                                         'FGA_RANK',
                                         'FG_PCT_RANK',
                                         'FG3M_RANK',
                                         'FG3A_RANK',
                                         'FG3_PCT_RANK',
                                         'FTM_RANK',
                                         'FTA_RANK',
                                         'FT_PCT_RANK',
                                         'OREB_RANK',
                                         'DREB_RANK',
                                         'REB_RANK',
                                         'AST_RANK',
                                         'TOV_RANK',
                                         'STL_RANK',
                                         'BLK_RANK',
                                         'BLKA_RANK',
                                         'PF_RANK',
                                         'PFD_RANK',
                                         'PTS_RANK',
                                         'PLUS_MINUS_RANK',
                                         'CFID',
                                         'CFPARAMS']

    assert list(example_rest.keys()) == ['GROUP_SET',
                                         'GROUP_VALUE',
                                         'TEAM_DAYS_REST_RANGE',
                                         'GP',
                                         'W',
                                         'L',
                                         'W_PCT',
                                         'MIN',
                                         'FGM',
                                         'FGA',
                                         'FG_PCT',
                                         'FG3M',
                                         'FG3A',
                                         'FG3_PCT',
                                         'FTM',
                                         'FTA',
                                         'FT_PCT',
                                         'OREB',
                                         'DREB',
                                         'REB',
                                         'AST',
                                         'TOV',
                                         'STL',
                                         'BLK',
                                         'BLKA',
                                         'PF',
                                         'PFD',
                                         'PTS',
                                         'PLUS_MINUS',
                                         'GP_RANK',
                                         'W_RANK',
                                         'L_RANK',
                                         'W_PCT_RANK',
                                         'MIN_RANK',
                                         'FGM_RANK',
                                         'FGA_RANK',
                                         'FG_PCT_RANK',
                                         'FG3M_RANK',
                                         'FG3A_RANK',
                                         'FG3_PCT_RANK',
                                         'FTM_RANK',
                                         'FTA_RANK',
                                         'FT_PCT_RANK',
                                         'OREB_RANK',
                                         'DREB_RANK',
                                         'REB_RANK',
                                         'AST_RANK',
                                         'TOV_RANK',
                                         'STL_RANK',
                                         'BLK_RANK',
                                         'BLKA_RANK',
                                         'PF_RANK',
                                         'PFD_RANK',
                                         'PTS_RANK',
                                         'PLUS_MINUS_RANK',
                                         'CFID',
                                         'CFPARAMS']

def test_team_lastngames():
    """ tests the teamdashboardbylastngames endpoint of the Team class
    """

    time.sleep(1)
    example_team = Team(headers=HEADERS,
                        endpoint='teamdashboardbylastngames')

    table_names = example_team.data.keys()

    assert 'OverallTeamDashboard' in table_names
    assert 'Last5TeamDashboard' in table_names
    assert 'Last10TeamDashboard' in table_names
    assert 'Last15TeamDashboard' in table_names
    assert 'Last20TeamDashboard' in table_names
    assert 'GameNumberTeamDashboard' in table_names

    example_overall = example_team.data['OverallTeamDashboard'][0]
    example_last5 = example_team.data['Last5TeamDashboard'][0]
    example_last10 = example_team.data['Last10TeamDashboard'][0]
    example_last15 = example_team.data['Last15TeamDashboard'][0]
    example_last20 = example_team.data['Last20TeamDashboard'][0]
    example_game = example_team.data['GameNumberTeamDashboard'][0]

    columns = ['GROUP_SET',
               'GROUP_VALUE',
               'GP',
               'W',
               'L',
               'W_PCT',
               'MIN',
               'FGM',
               'FGA',
               'FG_PCT',
               'FG3M',
               'FG3A',
               'FG3_PCT',
               'FTM',
               'FTA',
               'FT_PCT',
               'OREB',
               'DREB',
               'REB',
               'AST',
               'TOV',
               'STL',
               'BLK',
               'BLKA',
               'PF',
               'PFD',
               'PTS',
               'PLUS_MINUS',
               'GP_RANK',
               'W_RANK',
               'L_RANK',
               'W_PCT_RANK',
               'MIN_RANK',
               'FGM_RANK',
               'FGA_RANK',
               'FG_PCT_RANK',
               'FG3M_RANK',
               'FG3A_RANK',
               'FG3_PCT_RANK',
               'FTM_RANK',
               'FTA_RANK',
               'FT_PCT_RANK',
               'OREB_RANK',
               'DREB_RANK',
               'REB_RANK',
               'AST_RANK',
               'TOV_RANK',
               'STL_RANK',
               'BLK_RANK',
               'BLKA_RANK',
               'PF_RANK',
               'PFD_RANK',
               'PTS_RANK',
               'PLUS_MINUS_RANK',
               'CFID',
               'CFPARAMS']

    assert list(example_overall.keys()) == columns

    assert list(example_last5.keys()) == columns

    assert list(example_last10.keys()) == columns

    assert list(example_last15.keys()) == columns

    assert list(example_last20.keys()) == columns

    assert list(example_game.keys()) == columns
    
def test_team_opponent():
    """ tests the teamdashboardbyopponent endpoint of the Team class
    """

    time.sleep(1)
    example_team = Team(headers=HEADERS,
                          endpoint='teamdashboardbyopponent')

    table_names = example_team.data.keys()

    assert 'OverallTeamDashboard' in table_names
    assert 'ConferenceTeamDashboard' in table_names
    assert 'DivisionTeamDashboard' in table_names
    assert 'OpponentTeamDashboard' in table_names

    example_overall = example_team.data['OverallTeamDashboard'][0]
    example_conference = example_team.data['ConferenceTeamDashboard'][0]
    example_division = example_team.data['DivisionTeamDashboard'][0]
    example_opponent = example_team.data['OpponentTeamDashboard'][0]

    columns = ['GROUP_SET',
               'GROUP_VALUE',
               'GP',
               'W',
               'L',
               'W_PCT',
               'MIN',
               'FGM',
               'FGA',
               'FG_PCT',
               'FG3M',
               'FG3A',
               'FG3_PCT',
               'FTM',
               'FTA',
               'FT_PCT',
               'OREB',
               'DREB',
               'REB',
               'AST',
               'TOV',
               'STL',
               'BLK',
               'BLKA',
               'PF',
               'PFD',
               'PTS',
               'PLUS_MINUS',
               'GP_RANK',
               'W_RANK',
               'L_RANK',
               'W_PCT_RANK',
               'MIN_RANK',
               'FGM_RANK',
               'FGA_RANK',
               'FG_PCT_RANK',
               'FG3M_RANK',
               'FG3A_RANK',
               'FG3_PCT_RANK',
               'FTM_RANK',
               'FTA_RANK',
               'FT_PCT_RANK',
               'OREB_RANK',
               'DREB_RANK',
               'REB_RANK',
               'AST_RANK',
               'TOV_RANK',
               'STL_RANK',
               'BLK_RANK',
               'BLKA_RANK',
               'PF_RANK',
               'PFD_RANK',
               'PTS_RANK',
               'PLUS_MINUS_RANK',
               'CFID',
               'CFPARAMS']
    
    assert list(example_overall.keys()) == columns

    assert list(example_conference.keys()) == columns

    assert list(example_division.keys()) == columns

    assert list(example_opponent.keys()) == columns

def test_team_shootingsplits():
    """ tests the teamdashboardbyshootingsplits endpoint of the Team class
    """

    time.sleep(1)
    example_team = Team(headers=HEADERS,
                          endpoint='teamdashboardbyshootingsplits')

    table_names = example_team.data.keys()

    assert 'OverallTeamDashboard' in table_names
    assert 'Shot5FTTeamDashboard' in table_names
    assert 'Shot8FTTeamDashboard' in table_names
    assert 'ShotAreaTeamDashboard' in table_names
    assert 'AssitedShotTeamDashboard' in table_names
    assert 'ShotTypeTeamDashboard' in table_names
    assert 'AssistedBy' in table_names

    example_overall = example_team.data['OverallTeamDashboard'][0]
    example_5ft = example_team.data['Shot5FTTeamDashboard'][0]
    example_8ft = example_team.data['Shot8FTTeamDashboard'][0]
    example_area = example_team.data['ShotAreaTeamDashboard'][0]
    example_assisted = example_team.data['AssitedShotTeamDashboard'][0]
    example_type = example_team.data['ShotTypeTeamDashboard'][0]
    example_assistedby = example_team.data['AssistedBy'][0]

    columns = ['GROUP_SET',
               'GROUP_VALUE',
               'FGM',
               'FGA',
               'FG_PCT',
               'FG3M',
               'FG3A',
               'FG3_PCT',
               'EFG_PCT',
               'BLKA',
               'PCT_AST_2PM',
               'PCT_UAST_2PM',
               'PCT_AST_3PM',
               'PCT_UAST_3PM',
               'PCT_AST_FGM',
               'PCT_UAST_FGM',
               'FGM_RANK',
               'FGA_RANK',
               'FG_PCT_RANK',
               'FG3M_RANK',
               'FG3A_RANK',
               'FG3_PCT_RANK',
               'EFG_PCT_RANK',
               'BLKA_RANK',
               'PCT_AST_2PM_RANK',
               'PCT_UAST_2PM_RANK',
               'PCT_AST_3PM_RANK',
               'PCT_UAST_3PM_RANK',
               'PCT_AST_FGM_RANK',
               'PCT_UAST_FGM_RANK',
               'CFID',
               'CFPARAMS']

    assert list(example_overall.keys()) == columns

    assert list(example_5ft.keys()) == columns

    assert list(example_8ft.keys()) == columns

    assert list(example_area.keys()) == columns

    assert list(example_assisted.keys()) == columns

    assert list(example_type.keys()) == columns

    assert list(example_assistedby.keys()) == ['GROUP_SET',
                                               'PLAYER_ID',
                                               'PLAYER_NAME',
                                               'FGM',
                                               'FGA',
                                               'FG_PCT',
                                               'FG3M',
                                               'FG3A',
                                               'FG3_PCT',
                                               'EFG_PCT',
                                               'BLKA',
                                               'PCT_AST_2PM',
                                               'PCT_UAST_2PM',
                                               'PCT_AST_3PM',
                                               'PCT_UAST_3PM',
                                               'PCT_AST_FGM',
                                               'PCT_UAST_FGM',
                                               'FGM_RANK',
                                               'FGA_RANK',
                                               'FG_PCT_RANK',
                                               'FG3M_RANK',
                                               'FG3A_RANK',
                                               'FG3_PCT_RANK',
                                               'EFG_PCT_RANK',
                                               'BLKA_RANK',
                                               'PCT_AST_2PM_RANK',
                                               'PCT_UAST_2PM_RANK',
                                               'PCT_AST_3PM_RANK',
                                               'PCT_UAST_3PM_RANK',
                                               'PCT_AST_FGM_RANK',
                                               'PCT_UAST_FGM_RANK',
                                               'CFID',
                                               'CFPARAMS']

def test_team_teamperformance():
    """ tests the teamdashboardbyteamperformance endpoint of the Team class
    """

    time.sleep(1)
    example_team = Team(headers=HEADERS,
                        endpoint='teamdashboardbyteamperformance')

    table_names = example_team.data.keys()

    assert 'OverallTeamDashboard' in table_names
    assert 'ScoreDifferentialTeamDashboard' in table_names
    assert 'PointsScoredTeamDashboard' in table_names
    assert 'PontsAgainstTeamDashboard' in table_names

    example_overall = example_team.data['OverallTeamDashboard'][0]
    example_scorediff = example_team.data['ScoreDifferentialTeamDashboard'][0]
    example_scored = example_team.data['PointsScoredTeamDashboard'][0]
    example_against = example_team.data['PontsAgainstTeamDashboard'][0]

    columns = ['GROUP_SET',
               'GROUP_VALUE_ORDER',
               'GROUP_VALUE',
               'GROUP_VALUE_2',
               'GP',
               'W',
               'L',
               'W_PCT',
               'MIN',
               'FGM',
               'FGA',
               'FG_PCT',
               'FG3M',
               'FG3A',
               'FG3_PCT',
               'FTM',
               'FTA',
               'FT_PCT',
               'OREB',
               'DREB',
               'REB',
               'AST',
               'TOV',
               'STL',
               'BLK',
               'BLKA',
               'PF',
               'PFD',
               'PTS',
               'PLUS_MINUS',
               'GP_RANK',
               'W_RANK',
               'L_RANK',
               'W_PCT_RANK',
               'MIN_RANK',
               'FGM_RANK',
               'FGA_RANK',
               'FG_PCT_RANK',
               'FG3M_RANK',
               'FG3A_RANK',
               'FG3_PCT_RANK',
               'FTM_RANK',
               'FTA_RANK',
               'FT_PCT_RANK',
               'OREB_RANK',
               'DREB_RANK',
               'REB_RANK',
               'AST_RANK',
               'TOV_RANK',
               'STL_RANK',
               'BLK_RANK',
               'BLKA_RANK',
               'PF_RANK',
               'PFD_RANK',
               'PTS_RANK',
               'PLUS_MINUS_RANK',
               'CFID',
               'CFPARAMS']

    assert list(example_overall.keys()) == ['GROUP_SET',
                                            'GROUP_VALUE',
                                            'GP',
                                            'W',
                                            'L',
                                            'W_PCT',
                                            'MIN',
                                            'FGM',
                                            'FGA',
                                            'FG_PCT',
                                            'FG3M',
                                            'FG3A',
                                            'FG3_PCT',
                                            'FTM',
                                            'FTA',
                                            'FT_PCT',
                                            'OREB',
                                            'DREB',
                                            'REB',
                                            'AST',
                                            'TOV',
                                            'STL',
                                            'BLK',
                                            'BLKA',
                                            'PF',
                                            'PFD',
                                            'PTS',
                                            'PLUS_MINUS',
                                            'GP_RANK',
                                            'W_RANK',
                                            'L_RANK',
                                            'W_PCT_RANK',
                                            'MIN_RANK',
                                            'FGM_RANK',
                                            'FGA_RANK',
                                            'FG_PCT_RANK',
                                            'FG3M_RANK',
                                            'FG3A_RANK',
                                            'FG3_PCT_RANK',
                                            'FTM_RANK',
                                            'FTA_RANK',
                                            'FT_PCT_RANK',
                                            'OREB_RANK',
                                            'DREB_RANK',
                                            'REB_RANK',
                                            'AST_RANK',
                                            'TOV_RANK',
                                            'STL_RANK',
                                            'BLK_RANK',
                                            'BLKA_RANK',
                                            'PF_RANK',
                                            'PFD_RANK',
                                            'PTS_RANK',
                                            'PLUS_MINUS_RANK',
                                            'CFID',
                                            'CFPARAMS']

    assert list(example_scorediff.keys()) == columns

    assert list(example_scored.keys()) == columns

    assert list(example_against.keys()) == columns

def test_team_yoy():
    """ tests the teamdashboardbyyearoveryear endpoint of the Team class
    """

    time.sleep(1)
    example_team = Team(headers=HEADERS,
                        endpoint='teamdashboardbyyearoveryear')

    table_names = example_team.data.keys()

    assert 'OverallTeamDashboard' in table_names
    assert 'ByYearTeamDashboard' in table_names

    example_overall = example_team.data['OverallTeamDashboard'][0]
    example_yoy = example_team.data['ByYearTeamDashboard'][0]

    columns = ['GROUP_SET',
               'GROUP_VALUE',
               'GP',
               'W',
               'L',
               'W_PCT',
               'MIN',
               'FGM',
               'FGA',
               'FG_PCT',
               'FG3M',
               'FG3A',
               'FG3_PCT',
               'FTM',
               'FTA',
               'FT_PCT',
               'OREB',
               'DREB',
               'REB',
               'AST',
               'TOV',
               'STL',
               'BLK',
               'BLKA',
               'PF',
               'PFD',
               'PTS',
               'PLUS_MINUS',
               'GP_RANK',
               'W_RANK',
               'L_RANK',
               'W_PCT_RANK',
               'MIN_RANK',
               'FGM_RANK',
               'FGA_RANK',
               'FG_PCT_RANK',
               'FG3M_RANK',
               'FG3A_RANK',
               'FG3_PCT_RANK',
               'FTM_RANK',
               'FTA_RANK',
               'FT_PCT_RANK',
               'OREB_RANK',
               'DREB_RANK',
               'REB_RANK',
               'AST_RANK',
               'TOV_RANK',
               'STL_RANK',
               'BLK_RANK',
               'BLKA_RANK',
               'PF_RANK',
               'PFD_RANK',
               'PTS_RANK',
               'PLUS_MINUS_RANK',
               'CFID',
               'CFPARAMS']

    assert list(example_overall.keys()) == columns
    assert list(example_yoy.keys()) == columns

def test_team_lineups():
    """ tests the teamdashlineups endpoint of the Team class
    """

    time.sleep(1)
    example_team = Team(headers=HEADERS,
                        endpoint='teamdashlineups',
                        game_id='0021700608',
                        team_id='1610612745',
                        player_id='2772')

    table_names = example_team.data.keys()

    assert 'Overall' in table_names
    assert 'Lineups' in table_names

    example_overall = example_team.data['Overall'][0]
    example_lineups = example_team.data['Lineups'][0]

    assert list(example_overall.keys()) == ['GROUP_SET',
                                            'GROUP_VALUE',
                                            'TEAM_ID',
                                            'TEAM_ABBREVIATION',
                                            'TEAM_NAME',
                                            'GP',
                                            'W',
                                            'L',
                                            'W_PCT',
                                            'MIN',
                                            'FGM',
                                            'FGA',
                                            'FG_PCT',
                                            'FG3M',
                                            'FG3A',
                                            'FG3_PCT',
                                            'FTM',
                                            'FTA',
                                            'FT_PCT',
                                            'OREB',
                                            'DREB',
                                            'REB',
                                            'AST',
                                            'TOV',
                                            'STL',
                                            'BLK',
                                            'BLKA',
                                            'PF',
                                            'PFD',
                                            'PTS',
                                            'PLUS_MINUS',
                                            'GP_RANK',
                                            'W_RANK',
                                            'L_RANK',
                                            'W_PCT_RANK',
                                            'MIN_RANK',
                                            'FGM_RANK',
                                            'FGA_RANK',
                                            'FG_PCT_RANK',
                                            'FG3M_RANK',
                                            'FG3A_RANK',
                                            'FG3_PCT_RANK',
                                            'FTM_RANK',
                                            'FTA_RANK',
                                            'FT_PCT_RANK',
                                            'OREB_RANK',
                                            'DREB_RANK',
                                            'REB_RANK',
                                            'AST_RANK',
                                            'TOV_RANK',
                                            'STL_RANK',
                                            'BLK_RANK',
                                            'BLKA_RANK',
                                            'PF_RANK',
                                            'PFD_RANK',
                                            'PTS_RANK',
                                            'PLUS_MINUS_RANK']

    assert list(example_lineups.keys()) == ['GROUP_SET',
                                            'GROUP_ID',
                                            'GROUP_NAME',
                                            'GP',
                                            'W',
                                            'L',
                                            'W_PCT',
                                            'MIN',
                                            'FGM',
                                            'FGA',
                                            'FG_PCT',
                                            'FG3M',
                                            'FG3A',
                                            'FG3_PCT',
                                            'FTM',
                                            'FTA',
                                            'FT_PCT',
                                            'OREB',
                                            'DREB',
                                            'REB',
                                            'AST',
                                            'TOV',
                                            'STL',
                                            'BLK',
                                            'BLKA',
                                            'PF',
                                            'PFD',
                                            'PTS',
                                            'PLUS_MINUS',
                                            'GP_RANK',
                                            'W_RANK',
                                            'L_RANK',
                                            'W_PCT_RANK',
                                            'MIN_RANK',
                                            'FGM_RANK',
                                            'FGA_RANK',
                                            'FG_PCT_RANK',
                                            'FG3M_RANK',
                                            'FG3A_RANK',
                                            'FG3_PCT_RANK',
                                            'FTM_RANK',
                                            'FTA_RANK',
                                            'FT_PCT_RANK',
                                            'OREB_RANK',
                                            'DREB_RANK',
                                            'REB_RANK',
                                            'AST_RANK',
                                            'TOV_RANK',
                                            'STL_RANK',
                                            'BLK_RANK',
                                            'BLKA_RANK',
                                            'PF_RANK',
                                            'PFD_RANK',
                                            'PTS_RANK',
                                            'PLUS_MINUS_RANK']

def test_team_pass():
    """ tests the teamdashptpass endpoint of the Team class
    """

    time.sleep(1)
    example_team = Team(headers=HEADERS,
                        endpoint='teamdashptpass')

    table_names = example_team.data.keys()

    assert 'PassesMade' in table_names
    assert 'PassesReceived' in table_names

    example_made = example_team.data['PassesMade'][0]
    example_received = example_team.data['PassesReceived'][0]

    assert list(example_made.keys()) == ['TEAM_ID',
                                         'TEAM_NAME',
                                         'PASS_TYPE',
                                         'G',
                                         'PASS_FROM',
                                         'PASS_TEAMMATE_PLAYER_ID',
                                         'FREQUENCY',
                                         'PASS',
                                         'AST',
                                         'FGM',
                                         'FGA',
                                         'FG_PCT',
                                         'FG2M',
                                         'FG2A',
                                         'FG2_PCT',
                                         'FG3M',
                                         'FG3A',
                                         'FG3_PCT']

    assert list(example_received.keys()) == ['TEAM_ID',
                                             'TEAM_NAME',
                                             'PASS_TYPE',
                                             'G',
                                             'PASS_TO',
                                             'PASS_TEAMMATE_PLAYER_ID',
                                             'FREQUENCY',
                                             'PASS',
                                             'AST',
                                             'FGM',
                                             'FGA',
                                             'FG_PCT',
                                             'FG2M',
                                             'FG2A',
                                             'FG2_PCT',
                                             'FG3M',
                                             'FG3A',
                                             'FG3_PCT']

def test_team_reb():
    """ tests the teamdashptreb endpoint of the Team class
    """

    time.sleep(1)
    example_team = Team(headers=HEADERS,
                        endpoint='teamdashptreb')

    table_names = example_team.data.keys()

    assert 'OverallRebounding' in table_names
    assert 'ShotTypeRebounding' in table_names
    assert 'NumContestedRebounding' in table_names
    assert 'ShotDistanceRebounding' in table_names
    assert 'RebDistanceRebounding' in table_names

    example_overall = example_team.data['OverallRebounding'][0]
    example_type = example_team.data['ShotTypeRebounding'][0]
    example_num = example_team.data['NumContestedRebounding'][0]
    example_shotdist = example_team.data['ShotDistanceRebounding'][0]
    example_rebdist = example_team.data['RebDistanceRebounding'][0]

    assert list(example_overall.keys()) == ['TEAM_ID',
                                            'TEAM_NAME',
                                            'G',
                                            'OVERALL',
                                            'REB_FREQUENCY',
                                            'OREB',
                                            'DREB',
                                            'REB',
                                            'C_OREB',
                                            'C_DREB',
                                            'C_REB',
                                            'C_REB_PCT',
                                            'UC_OREB',
                                            'UC_DREB',
                                            'UC_REB',
                                            'UC_REB_PCT']

    assert list(example_type.keys()) == ['TEAM_ID',
                                         'TEAM_NAME',
                                         'SORT_ORDER',
                                         'G',
                                         'SHOT_TYPE_RANGE',
                                         'REB_FREQUENCY',
                                         'OREB',
                                         'DREB',
                                         'REB',
                                         'C_OREB',
                                         'C_DREB',
                                         'C_REB',
                                         'C_REB_PCT',
                                         'UC_OREB',
                                         'UC_DREB',
                                         'UC_REB',
                                         'UC_REB_PCT']

    assert list(example_num.keys()) == ['TEAM_ID',
                                        'TEAM_NAME',
                                        'SORT_ORDER',
                                        'G',
                                        'REB_NUM_CONTESTING_RANGE',
                                        'REB_FREQUENCY',
                                        'OREB',
                                        'DREB',
                                        'REB',
                                        'C_OREB',
                                        'C_DREB',
                                        'C_REB',
                                        'C_REB_PCT',
                                        'UC_OREB',
                                        'UC_DREB',
                                        'UC_REB',
                                        'UC_REB_PCT']

    assert list(example_shotdist.keys()) == ['TEAM_ID',
                                             'TEAM_NAME',
                                             'SORT_ORDER',
                                             'G',
                                             'SHOT_DIST_RANGE',
                                             'REB_FREQUENCY',
                                             'OREB',
                                             'DREB',
                                             'REB',
                                             'C_OREB',
                                             'C_DREB',
                                             'C_REB',
                                             'C_REB_PCT',
                                             'UC_OREB',
                                             'UC_DREB',
                                             'UC_REB',
                                             'UC_REB_PCT']

    assert list(example_rebdist.keys()) == ['TEAM_ID',
                                            'TEAM_NAME',
                                            'SORT_ORDER',
                                            'G',
                                            'REB_DIST_RANGE',
                                            'REB_FREQUENCY',
                                            'OREB',
                                            'DREB',
                                            'REB',
                                            'C_OREB',
                                            'C_DREB',
                                            'C_REB',
                                            'C_REB_PCT',
                                            'UC_OREB',
                                            'UC_DREB',
                                            'UC_REB',
                                            'UC_REB_PCT']

def test_team_shot():
    """ tests the teamdashptshots endpoint of the Team class
    """

    time.sleep(1)
    example_team = Team(headers=HEADERS,
                        endpoint='teamdashptshots')

    table_names = example_team.data.keys()

    assert 'GeneralShooting' in table_names
    assert 'ShotClockShooting' in table_names
    assert 'DribbleShooting' in table_names
    assert 'ClosestDefenderShooting' in table_names
    assert 'ClosestDefender10ftPlusShooting' in table_names
    assert 'TouchTimeShooting' in table_names

    example_gen = example_team.data['GeneralShooting'][0]
    example_clock = example_team.data['ShotClockShooting'][0]
    example_dribble = example_team.data['DribbleShooting'][0]
    example_defender = example_team.data['ClosestDefenderShooting'][0]
    example_defender10 = example_team.data['ClosestDefender10ftPlusShooting'][0]
    example_touch = example_team.data['TouchTimeShooting'][0]

    assert list(example_gen.keys()) == ['TEAM_ID',
                                       'TEAM_NAME',
                                       'SORT_ORDER',
                                       'G',
                                       'SHOT_TYPE',
                                       'FGA_FREQUENCY',
                                       'FGM',
                                       'FGA',
                                       'FG_PCT',
                                       'EFG_PCT',
                                       'FG2A_FREQUENCY',
                                       'FG2M',
                                       'FG2A',
                                       'FG2_PCT',
                                       'FG3A_FREQUENCY',
                                       'FG3M',
                                       'FG3A',
                                       'FG3_PCT']

    assert list(example_clock.keys()) == ['TEAM_ID',
                                          'TEAM_NAME',
                                          'SORT_ORDER',
                                          'G',
                                          'SHOT_CLOCK_RANGE',
                                          'FGA_FREQUENCY',
                                          'FGM',
                                          'FGA',
                                          'FG_PCT',
                                          'EFG_PCT',
                                          'FG2A_FREQUENCY',
                                          'FG2M',
                                          'FG2A',
                                          'FG2_PCT',
                                          'FG3A_FREQUENCY',
                                          'FG3M',
                                          'FG3A',
                                          'FG3_PCT']

    assert list(example_dribble.keys()) == ['TEAM_ID',
                                            'TEAM_NAME',
                                            'SORT_ORDER',
                                            'G',
                                            'DRIBBLE_RANGE',
                                            'FGA_FREQUENCY',
                                            'FGM',
                                            'FGA',
                                            'FG_PCT',
                                            'EFG_PCT',
                                            'FG2A_FREQUENCY',
                                            'FG2M',
                                            'FG2A',
                                            'FG2_PCT',
                                            'FG3A_FREQUENCY',
                                            'FG3M',
                                            'FG3A',
                                            'FG3_PCT']

    assert list(example_defender.keys()) == ['TEAM_ID',
                                             'TEAM_NAME',
                                             'SORT_ORDER',
                                             'G',
                                             'CLOSE_DEF_DIST_RANGE',
                                             'FGA_FREQUENCY',
                                             'FGM',
                                             'FGA',
                                             'FG_PCT',
                                             'EFG_PCT',
                                             'FG2A_FREQUENCY',
                                             'FG2M',
                                             'FG2A',
                                             'FG2_PCT',
                                             'FG3A_FREQUENCY',
                                             'FG3M',
                                             'FG3A',
                                             'FG3_PCT']

    assert list(example_defender10.keys()) == ['TEAM_ID',
                                               'TEAM_NAME',
                                               'SORT_ORDER',
                                               'G',
                                               'CLOSE_DEF_DIST_RANGE',
                                               'FGA_FREQUENCY',
                                               'FGM',
                                               'FGA',
                                               'FG_PCT',
                                               'EFG_PCT',
                                               'FG2A_FREQUENCY',
                                               'FG2M',
                                               'FG2A',
                                               'FG2_PCT',
                                               'FG3A_FREQUENCY',
                                               'FG3M',
                                               'FG3A',
                                               'FG3_PCT']

    assert list(example_touch.keys()) == ['TEAM_ID',
                                          'TEAM_NAME',
                                          'SORT_ORDER',
                                          'G',
                                          'TOUCH_TIME_RANGE',
                                          'FGA_FREQUENCY',
                                          'FGM',
                                          'FGA',
                                          'FG_PCT',
                                          'EFG_PCT',
                                          'FG2A_FREQUENCY',
                                          'FG2M',
                                          'FG2A',
                                          'FG2_PCT',
                                          'FG3A_FREQUENCY',
                                          'FG3M',
                                          'FG3A',
                                          'FG3_PCT']
    
def test_team_gamelog():
    """ tests the teamgamelog endpoint of the Team class
    """

    time.sleep(1)
    example_team = Team(headers=HEADERS,
                        endpoint='teamgamelog')

    table_names = example_team.data.keys()

    assert 'TeamGameLog' in table_names

    example_log = example_team.data['TeamGameLog'][0]

    assert list(example_log.keys()) == ['Team_ID',
                                        'Game_ID',
                                        'GAME_DATE',
                                        'MATCHUP',
                                        'WL',
                                        'W',
                                        'L',
                                        'W_PCT',
                                        'MIN',
                                        'FGM',
                                        'FGA',
                                        'FG_PCT',
                                        'FG3M',
                                        'FG3A',
                                        'FG3_PCT',
                                        'FTM',
                                        'FTA',
                                        'FT_PCT',
                                        'OREB',
                                        'DREB',
                                        'REB',
                                        'AST',
                                        'STL',
                                        'BLK',
                                        'TOV',
                                        'PF',
                                        'PTS']

def test_team_info():
    """ tests the teaminfocommon endpoint of the Team class
    """

    time.sleep(1)
    example_team = Team(headers=HEADERS,
                        endpoint='teaminfocommon')

    table_names = example_team.data.keys()

    assert 'TeamInfoCommon' in table_names
    assert 'TeamSeasonRanks' in table_names
    assert 'AvailableSeasons' in table_names

    example_info = example_team.data['TeamInfoCommon'][0]
    example_ranks = example_team.data['TeamSeasonRanks'][0]
    example_season = example_team.data['AvailableSeasons'][0]

    assert list(example_info.keys()) == ['TEAM_ID',
                                         'SEASON_YEAR',
                                         'TEAM_CITY',
                                         'TEAM_NAME',
                                         'TEAM_ABBREVIATION',
                                         'TEAM_CONFERENCE',
                                         'TEAM_DIVISION',
                                         'TEAM_CODE',
                                         'W',
                                         'L',
                                         'PCT',
                                         'CONF_RANK',
                                         'DIV_RANK',
                                         'MIN_YEAR',
                                         'MAX_YEAR']

    assert list(example_ranks.keys()) == ['LEAGUE_ID',
                                          'SEASON_ID',
                                          'TEAM_ID',
                                          'PTS_RANK',
                                          'PTS_PG',
                                          'REB_RANK',
                                          'REB_PG',
                                          'AST_RANK',
                                          'AST_PG',
                                          'OPP_PTS_RANK',
                                          'OPP_PTS_PG']

    assert list(example_season.keys()) == ['SEASON_ID']

def test_team_player():
    """ tests the teamplayerdashboard endpoint of the Player class
    """

    time.sleep(1)
    example_team = Team(headers=HEADERS,
                            player_id='203954',
                            endpoint='teamplayerdashboard')

    table_names = example_team.data.keys()

    assert 'TeamOverall' in table_names
    assert 'PlayersSeasonTotals' in table_names

    example_info = example_team.data['TeamOverall'][0]
    example_players = example_team.data['PlayersSeasonTotals'][0]

    columns = ['GROUP_SET',
               'TEAM_ID',
               'TEAM_NAME',
               'GROUP_VALUE',
               'GP',
               'W',
               'L',
               'W_PCT',
               'MIN',
               'FGM',
               'FGA',
               'FG_PCT',
               'FG3M',
               'FG3A',
               'FG3_PCT',
               'FTM',
               'FTA',
               'FT_PCT',
               'OREB',
               'DREB',
               'REB',
               'AST',
               'TOV',
               'STL',
               'BLK',
               'BLKA',
               'PF',
               'PFD',
               'PTS',
               'PLUS_MINUS',
               'GP_RANK',
               'W_RANK',
               'L_RANK',
               'W_PCT_RANK',
               'MIN_RANK',
               'FGM_RANK',
               'FGA_RANK',
               'FG_PCT_RANK',
               'FG3M_RANK',
               'FG3A_RANK',
               'FG3_PCT_RANK',
               'FTM_RANK',
               'FTA_RANK',
               'FT_PCT_RANK',
               'OREB_RANK',
               'DREB_RANK',
               'REB_RANK',
               'AST_RANK',
               'TOV_RANK',
               'STL_RANK',
               'BLK_RANK',
               'BLKA_RANK',
               'PF_RANK',
               'PFD_RANK',
               'PTS_RANK',
               'PLUS_MINUS_RANK']
    
    assert list(example_info.keys()) == columns

    assert list(example_players.keys()) == ['GROUP_SET',
                                            'PLAYER_ID',
                                            'PLAYER_NAME',
                                            'GP',
                                            'W',
                                            'L',
                                            'W_PCT',
                                            'MIN',
                                            'FGM',
                                            'FGA',
                                            'FG_PCT',
                                            'FG3M',
                                            'FG3A',
                                            'FG3_PCT',
                                            'FTM',
                                            'FTA',
                                            'FT_PCT',
                                            'OREB',
                                            'DREB',
                                            'REB',
                                            'AST',
                                            'TOV',
                                            'STL',
                                            'BLK',
                                            'BLKA',
                                            'PF',
                                            'PFD',
                                            'PTS',
                                            'PLUS_MINUS',
                                            'NBA_FANTASY_PTS',
                                            'DD2',
                                            'TD3',
                                            'GP_RANK',
                                            'W_RANK',
                                            'L_RANK',
                                            'W_PCT_RANK',
                                            'MIN_RANK',
                                            'FGM_RANK',
                                            'FGA_RANK',
                                            'FG_PCT_RANK',
                                            'FG3M_RANK',
                                            'FG3A_RANK',
                                            'FG3_PCT_RANK',
                                            'FTM_RANK',
                                            'FTA_RANK',
                                            'FT_PCT_RANK',
                                            'OREB_RANK',
                                            'DREB_RANK',
                                            'REB_RANK',
                                            'AST_RANK',
                                            'TOV_RANK',
                                            'STL_RANK',
                                            'BLK_RANK',
                                            'BLKA_RANK',
                                            'PF_RANK',
                                            'PFD_RANK',
                                            'PTS_RANK',
                                            'PLUS_MINUS_RANK',
                                            'NBA_FANTASY_PTS_RANK',
                                            'DD2_RANK',
                                            'TD3_RANK']

def test_team_onoff_details():
    """ tests the teamplayeronoffdetails endpoint of the Team class
    """

    time.sleep(1)
    example_team = Team(headers=HEADERS,
                        endpoint='teamplayeronoffdetails')

    table_names = example_team.data.keys()

    assert 'OverallTeamPlayerOnOffDetails' in table_names
    assert 'PlayersOnCourtTeamPlayerOnOffDetails' in table_names
    assert 'PlayersOffCourtTeamPlayerOnOffDetails' in table_names

    example_overall = example_team.data['OverallTeamPlayerOnOffDetails'][0]
    example_on = example_team.data['PlayersOnCourtTeamPlayerOnOffDetails'][0]
    example_off = example_team.data['PlayersOffCourtTeamPlayerOnOffDetails'][0]

    assert list(example_overall.keys()) == ['GROUP_SET',
                                            'GROUP_VALUE',
                                            'TEAM_ID',
                                            'TEAM_ABBREVIATION',
                                            'TEAM_NAME',
                                            'GP',
                                            'W',
                                            'L',
                                            'W_PCT',
                                            'MIN',
                                            'FGM',
                                            'FGA',
                                            'FG_PCT',
                                            'FG3M',
                                            'FG3A',
                                            'FG3_PCT',
                                            'FTM',
                                            'FTA',
                                            'FT_PCT',
                                            'OREB',
                                            'DREB',
                                            'REB',
                                            'AST',
                                            'TOV',
                                            'STL',
                                            'BLK',
                                            'BLKA',
                                            'PF',
                                            'PFD',
                                            'PTS',
                                            'PLUS_MINUS',
                                            'GP_RANK',
                                            'W_RANK',
                                            'L_RANK',
                                            'W_PCT_RANK',
                                            'MIN_RANK',
                                            'FGM_RANK',
                                            'FGA_RANK',
                                            'FG_PCT_RANK',
                                            'FG3M_RANK',
                                            'FG3A_RANK',
                                            'FG3_PCT_RANK',
                                            'FTM_RANK',
                                            'FTA_RANK',
                                            'FT_PCT_RANK',
                                            'OREB_RANK',
                                            'DREB_RANK',
                                            'REB_RANK',
                                            'AST_RANK',
                                            'TOV_RANK',
                                            'STL_RANK',
                                            'BLK_RANK',
                                            'BLKA_RANK',
                                            'PF_RANK',
                                            'PFD_RANK',
                                            'PTS_RANK',
                                            'PLUS_MINUS_RANK'] 

    assert list(example_on.keys()) == ['GROUP_SET',
                                       'TEAM_ID',
                                       'TEAM_ABBREVIATION',
                                       'TEAM_NAME',
                                       'VS_PLAYER_ID',
                                       'VS_PLAYER_NAME',
                                       'COURT_STATUS',
                                       'GP',
                                       'W',
                                       'L',
                                       'W_PCT',
                                       'MIN',
                                       'FGM',
                                       'FGA',
                                       'FG_PCT',
                                       'FG3M',
                                       'FG3A',
                                       'FG3_PCT',
                                       'FTM',
                                       'FTA',
                                       'FT_PCT',
                                       'OREB',
                                       'DREB',
                                       'REB',
                                       'AST',
                                       'TOV',
                                       'STL',
                                       'BLK',
                                       'BLKA',
                                       'PF',
                                       'PFD',
                                       'PTS',
                                       'PLUS_MINUS',
                                       'GP_RANK',
                                       'W_RANK',
                                       'L_RANK',
                                       'W_PCT_RANK',
                                       'MIN_RANK',
                                       'FGM_RANK',
                                       'FGA_RANK',
                                       'FG_PCT_RANK',
                                       'FG3M_RANK',
                                       'FG3A_RANK',
                                       'FG3_PCT_RANK',
                                       'FTM_RANK',
                                       'FTA_RANK',
                                       'FT_PCT_RANK',
                                       'OREB_RANK',
                                       'DREB_RANK',
                                       'REB_RANK',
                                       'AST_RANK',
                                       'TOV_RANK',
                                       'STL_RANK',
                                       'BLK_RANK',
                                       'BLKA_RANK',
                                       'PF_RANK',
                                       'PFD_RANK',
                                       'PTS_RANK',
                                       'PLUS_MINUS_RANK']

    assert list(example_off.keys()) == ['GROUP_SET',
                                       'TEAM_ID',
                                       'TEAM_ABBREVIATION',
                                       'TEAM_NAME',
                                       'VS_PLAYER_ID',
                                       'VS_PLAYER_NAME',
                                       'COURT_STATUS',
                                       'GP',
                                       'W',
                                       'L',
                                       'W_PCT',
                                       'MIN',
                                       'FGM',
                                       'FGA',
                                       'FG_PCT',
                                       'FG3M',
                                       'FG3A',
                                       'FG3_PCT',
                                       'FTM',
                                       'FTA',
                                       'FT_PCT',
                                       'OREB',
                                       'DREB',
                                       'REB',
                                       'AST',
                                       'TOV',
                                       'STL',
                                       'BLK',
                                       'BLKA',
                                       'PF',
                                       'PFD',
                                       'PTS',
                                       'PLUS_MINUS',
                                       'GP_RANK',
                                       'W_RANK',
                                       'L_RANK',
                                       'W_PCT_RANK',
                                       'MIN_RANK',
                                       'FGM_RANK',
                                       'FGA_RANK',
                                       'FG_PCT_RANK',
                                       'FG3M_RANK',
                                       'FG3A_RANK',
                                       'FG3_PCT_RANK',
                                       'FTM_RANK',
                                       'FTA_RANK',
                                       'FT_PCT_RANK',
                                       'OREB_RANK',
                                       'DREB_RANK',
                                       'REB_RANK',
                                       'AST_RANK',
                                       'TOV_RANK',
                                       'STL_RANK',
                                       'BLK_RANK',
                                       'BLKA_RANK',
                                       'PF_RANK',
                                       'PFD_RANK',
                                       'PTS_RANK',
                                       'PLUS_MINUS_RANK']
    
def test_team_onoff_summary():
    """ tests the teamplayeronoffsummary endpoint of the Team class
    """

    time.sleep(1)
    example_team = Team(headers=HEADERS,
                        endpoint='teamplayeronoffsummary')

    table_names = example_team.data.keys()

    assert 'OverallTeamPlayerOnOffSummary' in table_names
    assert 'PlayersOnCourtTeamPlayerOnOffSummary' in table_names
    assert 'PlayersOffCourtTeamPlayerOnOffSummary' in table_names

    example_overall = example_team.data['OverallTeamPlayerOnOffSummary'][0]
    example_on = example_team.data['PlayersOnCourtTeamPlayerOnOffSummary'][0]
    example_off = example_team.data['PlayersOffCourtTeamPlayerOnOffSummary'][0]

    assert list(example_overall.keys()) == ['GROUP_SET',
                                            'GROUP_VALUE',
                                            'TEAM_ID',
                                            'TEAM_ABBREVIATION',
                                            'TEAM_NAME',
                                            'GP',
                                            'W',
                                            'L',
                                            'W_PCT',
                                            'MIN',
                                            'FGM',
                                            'FGA',
                                            'FG_PCT',
                                            'FG3M',
                                            'FG3A',
                                            'FG3_PCT',
                                            'FTM',
                                            'FTA',
                                            'FT_PCT',
                                            'OREB',
                                            'DREB',
                                            'REB',
                                            'AST',
                                            'TOV',
                                            'STL',
                                            'BLK',
                                            'BLKA',
                                            'PF',
                                            'PFD',
                                            'PTS',
                                            'PLUS_MINUS',
                                            'GP_RANK',
                                            'W_RANK',
                                            'L_RANK',
                                            'W_PCT_RANK',
                                            'MIN_RANK',
                                            'FGM_RANK',
                                            'FGA_RANK',
                                            'FG_PCT_RANK',
                                            'FG3M_RANK',
                                            'FG3A_RANK',
                                            'FG3_PCT_RANK',
                                            'FTM_RANK',
                                            'FTA_RANK',
                                            'FT_PCT_RANK',
                                            'OREB_RANK',
                                            'DREB_RANK',
                                            'REB_RANK',
                                            'AST_RANK',
                                            'TOV_RANK',
                                            'STL_RANK',
                                            'BLK_RANK',
                                            'BLKA_RANK',
                                            'PF_RANK',
                                            'PFD_RANK',
                                            'PTS_RANK',
                                            'PLUS_MINUS_RANK'] 

    assert list(example_on.keys()) == ['GROUP_SET',
                                       'TEAM_ID',
                                       'TEAM_ABBREVIATION',
                                       'TEAM_NAME',
                                       'VS_PLAYER_ID',
                                       'VS_PLAYER_NAME',
                                       'COURT_STATUS',
                                       'GP',
                                       'MIN',
                                       'PLUS_MINUS',
                                       'OFF_RATING',
                                       'DEF_RATING',
                                       'NET_RATING']

    assert list(example_off.keys()) == ['GROUP_SET',
                                       'TEAM_ID',
                                       'TEAM_ABBREVIATION',
                                       'TEAM_NAME',
                                       'VS_PLAYER_ID',
                                       'VS_PLAYER_NAME',
                                       'COURT_STATUS',
                                       'GP',
                                       'MIN',
                                       'PLUS_MINUS',
                                       'OFF_RATING',
                                       'DEF_RATING',
                                       'NET_RATING']

def test_team_v_player():
    """ tests the teamvsplayer endpoint of the Player class
    """

    time.sleep(1)
    example_team = Team(headers=HEADERS,
                        endpoint='teamvsplayer')

    table_names = example_team.data.keys()

    assert 'Overall' in table_names
    assert 'vsPlayerOverall' in table_names
    assert 'OnOffCourt' in table_names
    assert 'ShotDistanceOverall' in table_names
    assert 'ShotDistanceOnCourt' in table_names
    assert 'ShotDistanceOffCourt' in table_names
    assert 'ShotAreaOverall' in table_names
    assert 'ShotAreaOnCourt' in table_names
    assert 'ShotAreaOffCourt' in table_names

    example_overall = example_team.data['Overall'][0]
    example_vs_overall = example_team.data['vsPlayerOverall'][0]
    example_on_off = example_team.data['OnOffCourt'][0]
    example_dist = example_team.data['ShotDistanceOverall'][0]
    example_dist_on = example_team.data['ShotDistanceOnCourt'][0]
    example_dist_off = example_team.data['ShotDistanceOffCourt'][0]
    example_area = example_team.data['ShotAreaOverall'][0]
    example_area_on = example_team.data['ShotAreaOnCourt'][0]
    example_area_off = example_team.data['ShotAreaOffCourt'][0]

    assert list(example_overall.keys()) == ['GROUP_SET',
                                            'GROUP_VALUE',
                                            'TEAM_ID',
                                            'TEAM_ABBREVIATION',
                                            'GP',
                                            'W',
                                            'L',
                                            'W_PCT',
                                            'MIN',
                                            'FGM',
                                            'FGA',
                                            'FG_PCT',
                                            'FG3M',
                                            'FG3A',
                                            'FG3_PCT',
                                            'FTM',
                                            'FTA',
                                            'FT_PCT',
                                            'OREB',
                                            'DREB',
                                            'REB',
                                            'AST',
                                            'TOV',
                                            'STL',
                                            'BLK',
                                            'BLKA',
                                            'PF',
                                            'PFD',
                                            'PTS',
                                            'PLUS_MINUS',
                                            'GP_RANK',
                                            'W_RANK',
                                            'L_RANK',
                                            'W_PCT_RANK',
                                            'MIN_RANK',
                                            'FGM_RANK',
                                            'FGA_RANK',
                                            'FG_PCT_RANK',
                                            'FG3M_RANK',
                                            'FG3A_RANK',
                                            'FG3_PCT_RANK',
                                            'FTM_RANK',
                                            'FTA_RANK',
                                            'FT_PCT_RANK',
                                            'OREB_RANK',
                                            'DREB_RANK',
                                            'REB_RANK',
                                            'AST_RANK',
                                            'TOV_RANK',
                                            'STL_RANK',
                                            'BLK_RANK',
                                            'BLKA_RANK',
                                            'PF_RANK',
                                            'PFD_RANK',
                                            'PTS_RANK',
                                            'PLUS_MINUS_RANK',
                                            'CFID',
                                            'CFPARAMS']

    assert list(example_vs_overall.keys()) == ['GROUP_SET',
                                               'GROUP_VALUE',
                                               'PLAYER_ID',
                                               'GP',
                                               'W',
                                               'L',
                                               'W_PCT',
                                               'MIN',
                                               'FGM',
                                               'FGA',
                                               'FG_PCT',
                                               'FG3M',
                                               'FG3A',
                                               'FG3_PCT',
                                               'FTM',
                                               'FTA',
                                               'FT_PCT',
                                               'OREB',
                                               'DREB',
                                               'REB',
                                               'AST',
                                               'TOV',
                                               'STL',
                                               'BLK',
                                               'BLKA',
                                               'PF',
                                               'PFD',
                                               'PTS',
                                               'PLUS_MINUS',
                                               'NBA_FANTASY_PTS',
                                               'DD2',
                                               'TD3',
                                               'GP_RANK',
                                               'W_RANK',
                                               'L_RANK',
                                               'W_PCT_RANK',
                                               'MIN_RANK',
                                               'FGM_RANK',
                                               'FGA_RANK',
                                               'FG_PCT_RANK',
                                               'FG3M_RANK',
                                               'FG3A_RANK',
                                               'FG3_PCT_RANK',
                                               'FTM_RANK',
                                               'FTA_RANK',
                                               'FT_PCT_RANK',
                                               'OREB_RANK',
                                               'DREB_RANK',
                                               'REB_RANK',
                                               'AST_RANK',
                                               'TOV_RANK',
                                               'STL_RANK',
                                               'BLK_RANK',
                                               'BLKA_RANK',
                                               'PF_RANK',
                                               'PFD_RANK',
                                               'PTS_RANK',
                                               'PLUS_MINUS_RANK',
                                               'NBA_FANTASY_PTS_RANK',
                                               'DD2_RANK',
                                               'TD3_RANK',
                                               'CFID',
                                               'CFPARAMS']
    
    assert list(example_on_off.keys()) == ['GROUP_SET',
                                           'TEAM_ID',
                                           'TEAM_ABBREVIATION',
                                           'TEAM_NAME',
                                           'VS_PLAYER_ID',
                                           'VS_PLAYER_NAME',
                                           'COURT_STATUS',
                                           'GP',
                                           'W',
                                           'L',
                                           'W_PCT',
                                           'MIN',
                                           'FGM',
                                           'FGA',
                                           'FG_PCT',
                                           'FG3M',
                                           'FG3A',
                                           'FG3_PCT',
                                           'FTM',
                                           'FTA',
                                           'FT_PCT',
                                           'OREB',
                                           'DREB',
                                           'REB',
                                           'AST',
                                           'TOV',
                                           'STL',
                                           'BLK',
                                           'BLKA',
                                           'PF',
                                           'PFD',
                                           'PTS',
                                           'PLUS_MINUS',
                                           'GP_RANK',
                                           'W_RANK',
                                           'L_RANK',
                                           'W_PCT_RANK',
                                           'MIN_RANK',
                                           'FGM_RANK',
                                           'FGA_RANK',
                                           'FG_PCT_RANK',
                                           'FG3M_RANK',
                                           'FG3A_RANK',
                                           'FG3_PCT_RANK',
                                           'FTM_RANK',
                                           'FTA_RANK',
                                           'FT_PCT_RANK',
                                           'OREB_RANK',
                                           'DREB_RANK',
                                           'REB_RANK',
                                           'AST_RANK',
                                           'TOV_RANK',
                                           'STL_RANK',
                                           'BLK_RANK',
                                           'BLKA_RANK',
                                           'PF_RANK',
                                           'PFD_RANK',
                                           'PTS_RANK',
                                           'PLUS_MINUS_RANK',
                                           'CFID',
                                           'CFPARAMS']

    assert list(example_dist.keys()) == ['GROUP_SET',
                                         'GROUP_VALUE',
                                         'TEAM_ID',
                                         'TEAM_ABBREVIATION',
                                         'TEAM_NAME',
                                         'FGM',
                                         'FGA',
                                         'FG_PCT',
                                         'CFID',
                                         'CFPARAMS']

    assert list(example_dist_on.keys()) == ['GROUP_SET',
                                            'TEAM_ID',
                                            'TEAM_ABBREVIATION',
                                            'TEAM_NAME',
                                            'VS_PLAYER_ID',
                                            'VS_PLAYER_NAME',
                                            'COURT_STATUS',
                                            'GROUP_VALUE',
                                            'FGM',
                                            'FGA',
                                            'FG_PCT',
                                            'CFID',
                                            'CFPARAMS']

    assert list(example_dist_off.keys()) == ['GROUP_SET',
                                            'TEAM_ID',
                                            'TEAM_ABBREVIATION',
                                            'TEAM_NAME',
                                            'VS_PLAYER_ID',
                                            'VS_PLAYER_NAME',
                                            'COURT_STATUS',
                                            'GROUP_VALUE',
                                            'FGM',
                                            'FGA',
                                            'FG_PCT',
                                            'CFID',
                                            'CFPARAMS']

    assert list(example_area.keys()) == ['GROUP_SET',
                                         'GROUP_VALUE',
                                         'TEAM_ID',
                                         'TEAM_ABBREVIATION',
                                         'TEAM_NAME',
                                         'FGM',
                                         'FGA',
                                         'FG_PCT',
                                         'CFID',
                                         'CFPARAMS']

    assert list(example_area_on.keys()) == ['GROUP_SET',
                                            'TEAM_ID',
                                            'TEAM_ABBREVIATION',
                                            'TEAM_NAME',
                                            'VS_PLAYER_ID',
                                            'VS_PLAYER_NAME',
                                            'COURT_STATUS',
                                            'GROUP_VALUE',
                                            'FGM',
                                            'FGA',
                                            'FG_PCT',
                                            'CFID',
                                            'CFPARAMS']

    assert list(example_area_off.keys()) == ['GROUP_SET',
                                            'TEAM_ID',
                                            'TEAM_ABBREVIATION',
                                            'TEAM_NAME',
                                            'VS_PLAYER_ID',
                                            'VS_PLAYER_NAME',
                                            'COURT_STATUS',
                                            'GROUP_VALUE',
                                            'FGM',
                                            'FGA',
                                            'FG_PCT',
                                            'CFID',
                                            'CFPARAMS']

def test_team_stats():
    """ tests the teamyearbyyearstats endpoint of the Team class
    """

    time.sleep(1)
    example_team = Team(headers=HEADERS,
                        endpoint='teamyearbyyearstats')

    table_names = example_team.data.keys()

    assert 'TeamStats' in table_names

    example_stats = example_team.data['TeamStats'][0]

    assert list(example_stats.keys()) == ['TEAM_ID',
                                          'TEAM_CITY',
                                          'TEAM_NAME',
                                          'YEAR',
                                          'GP',
                                          'WINS',
                                          'LOSSES',
                                          'WIN_PCT',
                                          'CONF_RANK',
                                          'DIV_RANK',
                                          'PO_WINS',
                                          'PO_LOSSES',
                                          'CONF_COUNT',
                                          'DIV_COUNT',
                                          'NBA_FINALS_APPEARANCE',
                                          'FGM',
                                          'FGA',
                                          'FG_PCT',
                                          'FG3M',
                                          'FG3A',
                                          'FG3_PCT',
                                          'FTM',
                                          'FTA',
                                          'FT_PCT',
                                          'OREB',
                                          'DREB',
                                          'REB',
                                          'AST',
                                          'PF',
                                          'STL',
                                          'TOV',
                                          'BLK',
                                          'PTS',
                                          'PTS_RANK']



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Tue Oct  9 19:29:03 2018

@author: patrickmcfarlane

playbyplay.py contains the PlayByPlay class that
enables API calls for two play-by-play (pbp) endpoints
"""

from .utils import api_call, parse_api_call

class PlayByPlay:
    """ The PlayByPlay class contains all resources needed to use the 
    pbp-related API calls. `stats.nba.com <https://stats.nba.com>`_
    has the following pbp-related API endpoints:

        - **playbyplay**: Game play-by-play with basic fields, such as \
        play desscription, score, margin, period, and game time.
        - **playbyplayv2**: Game play-by-play with the basic fields above, \
        as well as player information of those involved in the play.

    The PlayByPlay class has the following required parameters:

        @param **headers** (*dict*): Dictionary of request header information
            required by the API. Specifically, the API requires you to declare
            the 'User-Agent' key of the request header dictionary. More information
            can be found `here <https://stackoverflow.com/questions/46781563/
            how-to-obtain-a-json-response-from-the-stats-nba-com-api>`_ and
            an example request header dictionary can be found in the __init__.py
            file in the tests folder of this module.

        @param **game_id** (*str*): GameID in the API. 10-digit string \
            that represents a unique game. The format is two leading zeroes, \
            followed by a season indicator number ('1' for preseason, \
            '2' for regular season, '4' for the post-season), \
            then the trailing digits of the season in which the game \
            took place (e.g. '17' for the 2017-18 season). The following \
            5 digits increment from '00001' in order as the season progresses. \
            For example, '0021600001' is the **game_id** of the first game \
            of the 2016-17 NBA regular season.

        @param **start_period** (*str*): StartPeriod in the API. String of \
            an integer that corresponds to the period for which the \
            boxscore begins.

        @param **end_period** (*str*): EndPeriod in the API. String of an \
            integer that corresponds to the period for which the \
            boxscore ends (Overtime increments logically, e.g. '5' is \
            the first overtime period).

    Attributes:

        **api_resp** (*dict*): JSON object of the API response. The API \
            response has three keys. The 'resource' key describes the \
            type of response returned ('playbyplay' in this instance). \
            The 'parameters' key describes the parameters provided in \
            the API call. The 'resultSets' key contains the data returned \
            in the API call.

        **data** (*dict*): A dictionary of response names. Each response \
            name is a key to a list of dictionaries containing the \
            corresponding data.
    """

    def __init__(self, headers, game_id, endpoint='playbyplay',
                 start_period='1', end_period='10'):

        # Controlling the parameters depending on the endpoint
        params = {'GameID': game_id,
                  'StartPeriod': start_period,
                  'EndPeriod': end_period}

        self.api_resp = api_call(endpoint=endpoint,
                                 params=params,
                                 headers=headers)

        # Storing the API response in a dictionary called data
        # The results can come in different formats, namely a
        # dictionary keyed by either resultSets or resultSet
        self.data = parse_api_call(self.api_resp)
